@@ -6,23 +6,19 @@
 # See LICENSE for details.
 # --- END COPYRIGHT BLOCK ---
 #
-import os
-import time
-import ldap
-import logging
-import pytest
 from subprocess import Popen
-from lib389 import DirSrv, Entry
-from lib389._constants import *
-from lib389.properties import *
+
+import pytest
+from lib389.paths import Paths
 from lib389.tasks import *
 from lib389.utils import *
+from lib389.topologies import topology_st
+
+from lib389._constants import DN_DM, DEFAULT_SUFFIX, PASSWORD, SERVERID_STANDALONE
 
 logging.getLogger(__name__).setLevel(logging.DEBUG)
 log = logging.getLogger(__name__)
 
-installation1_prefix = None
-
 CONFIG_DN = 'cn=config'
 BOU = 'BOU'
 BINDOU = 'ou=%s,%s' % (BOU, DEFAULT_SUFFIX)
@@ -38,48 +34,6 @@ BOGUSSUFFIX = 'uid=bogus,ou=people,dc=bogus'
 GROUPOU = 'ou=groups,%s' % DEFAULT_SUFFIX
 BOGUSOU = 'ou=OU,%s' % DEFAULT_SUFFIX
 
-logging.getLogger(__name__).setLevel(logging.DEBUG)
-log = logging.getLogger(__name__)
-
-installation1_prefix = None
-
-
-class TopologyStandalone(object):
-    def __init__(self, standalone):
-        standalone.open()
-        self.standalone = standalone
-
-
-@pytest.fixture(scope="module")
-def topology(request):
-    global installation1_prefix
-    if installation1_prefix:
-        args_instance[SER_DEPLOYED_DIR] = installation1_prefix
-
-    # Creating standalone instance ...
-    standalone = DirSrv(verbose=False)
-    args_instance[SER_HOST] = HOST_STANDALONE
-    args_instance[SER_PORT] = PORT_STANDALONE
-    args_instance[SER_SERVERID_PROP] = SERVERID_STANDALONE
-    args_instance[SER_CREATION_SUFFIX] = DEFAULT_SUFFIX
-    args_standalone = args_instance.copy()
-    standalone.allocate(args_standalone)
-    instance_standalone = standalone.exists()
-    if instance_standalone:
-        standalone.delete()
-    standalone.create()
-    standalone.open()
-
-    # Delete each instance in the end
-    def fin():
-        standalone.delete()
-    request.addfinalizer(fin)
-
-    # Clear out the tmp dir
-    standalone.clearTmpDir(__file__)
-
-    return TopologyStandalone(standalone)
-
 
 def pattern_accesslog(file, log_pattern):
     for i in range(5):
@@ -125,7 +79,7 @@ def check_op_result(server, op, dn, superior, exists, rc):
         else:
             opstr = 'Modifying non-existing entry'
     elif op == 'modrdn':
-        if superior != None:
+        if superior is not None:
             targetdn = superior
             if exists:
                 opstr = 'Moving to existing superior'
@@ -159,7 +113,7 @@ def check_op_result(server, op, dn, superior, exists, rc):
         elif op == 'modify':
             server.modify_s(dn, [(ldap.MOD_REPLACE, 'description', 'test')])
         elif op == 'modrdn':
-            if superior != None:
+            if superior is not None:
                 server.rename_s(dn, 'uid=new', newsuperior=superior, delold=1)
             else:
                 server.rename_s(dn, 'uid=new', delold=1)
@@ -173,7 +127,7 @@ def check_op_result(server, op, dn, superior, exists, rc):
         log.info("Exception (expected): %s" % type(e).__name__)
         log.info('Desc ' + e.message['desc'])
         assert isinstance(e, rc)
-        if e.message.has_key('matched'):
+        if 'matched' in e.message:
             log.info('Matched is returned: ' + e.message['matched'])
             if rc != ldap.NO_SUCH_OBJECT:
                 assert False
@@ -190,97 +144,101 @@ def check_op_result(server, op, dn, superior, exists, rc):
     log.info('PASSED\n')
 
 
-def test_ticket1347760(topology):
+def test_ticket1347760(topology_st):
     """
     Prevent revealing the entry info to whom has no access rights.
     """
     log.info('Testing Bug 1347760 - Information disclosure via repeated use of LDAP ADD operation, etc.')
 
     log.info('Disabling accesslog logbuffering')
-    topology.standalone.modify_s(CONFIG_DN, [(ldap.MOD_REPLACE, 'nsslapd-accesslog-logbuffering', 'off')])
+    topology_st.standalone.modify_s(CONFIG_DN, [(ldap.MOD_REPLACE, 'nsslapd-accesslog-logbuffering', 'off')])
 
     log.info('Bind as {%s,%s}' % (DN_DM, PASSWORD))
-    topology.standalone.simple_bind_s(DN_DM, PASSWORD)
+    topology_st.standalone.simple_bind_s(DN_DM, PASSWORD)
 
     log.info('Adding ou=%s a bind user belongs to.' % BOU)
-    topology.standalone.add_s(Entry((BINDOU, {
-                              'objectclass': 'top organizationalunit'.split(),
-                              'ou': BOU})))
+    topology_st.standalone.add_s(Entry((BINDOU, {
+        'objectclass': 'top organizationalunit'.split(),
+        'ou': BOU})))
 
     log.info('Adding a bind user.')
-    topology.standalone.add_s(Entry((BINDDN,
-                                     {'objectclass': "top person organizationalPerson inetOrgPerson".split(),
-                                      'cn': 'bind user',
-                                      'sn': 'user',
-                                      'userPassword': BINDPW})))
+    topology_st.standalone.add_s(Entry((BINDDN,
+                                        {'objectclass': "top person organizationalPerson inetOrgPerson".split(),
+                                         'cn': 'bind user',
+                                         'sn': 'user',
+                                         'userPassword': BINDPW})))
 
     log.info('Adding a test user.')
-    topology.standalone.add_s(Entry((TESTDN,
-                                     {'objectclass': "top person organizationalPerson inetOrgPerson".split(),
-                                      'cn': 'test user',
-                                      'sn': 'user',
-                                      'userPassword': TESTPW})))
+    topology_st.standalone.add_s(Entry((TESTDN,
+                                        {'objectclass': "top person organizationalPerson inetOrgPerson".split(),
+                                         'cn': 'test user',
+                                         'sn': 'user',
+                                         'userPassword': TESTPW})))
 
     log.info('Deleting aci in %s.' % DEFAULT_SUFFIX)
-    topology.standalone.modify_s(DEFAULT_SUFFIX, [(ldap.MOD_DELETE, 'aci', None)])
+    topology_st.standalone.modify_s(DEFAULT_SUFFIX, [(ldap.MOD_DELETE, 'aci', None)])
+
+    log.info('While binding as DM, acquire an access log path and instance dir')
+    ds_paths = Paths(serverid=topology_st.standalone.serverid,
+                     instance=topology_st.standalone)
+    file_path = ds_paths.access_log
+    inst_dir = ds_paths.inst_dir
 
     log.info('Bind case 1. the bind user has no rights to read the entry itself, bind should be successful.')
     log.info('Bind as {%s,%s} who has no access rights.' % (BINDDN, BINDPW))
     try:
-        topology.standalone.simple_bind_s(BINDDN, BINDPW)
+        topology_st.standalone.simple_bind_s(BINDDN, BINDPW)
     except ldap.LDAPError as e:
         log.info('Desc ' + e.message['desc'])
         assert False
 
-    file_path = os.path.join(topology.standalone.prefix, 'var/log/dirsrv/slapd-%s/access' % topology.standalone.serverid)
     file_obj = open(file_path, "r")
     log.info('Access log path: %s' % file_path)
 
-    log.info('Bind case 2-1. the bind user does not exist, bind should fail with error %s' % ldap.INVALID_CREDENTIALS.__name__)
+    log.info(
+        'Bind case 2-1. the bind user does not exist, bind should fail with error %s' % ldap.INVALID_CREDENTIALS.__name__)
     log.info('Bind as {%s,%s} who does not exist.' % (BOGUSDN, 'bogus'))
     try:
-        topology.standalone.simple_bind_s(BOGUSDN, 'bogus')
+        topology_st.standalone.simple_bind_s(BOGUSDN, 'bogus')
     except ldap.LDAPError as e:
         log.info("Exception (expected): %s" % type(e).__name__)
         log.info('Desc ' + e.message['desc'])
         assert isinstance(e, ldap.INVALID_CREDENTIALS)
         regex = re.compile('No such entry')
         cause = pattern_accesslog(file_obj, regex)
-        if cause == None:
+        if cause is None:
             log.fatal('Cause not found - %s' % cause)
             assert False
         else:
             log.info('Cause found - %s' % cause)
     time.sleep(1)
 
-    log.info('Bind case 2-2. the bind user\'s suffix does not exist, bind should fail with error %s' % ldap.INVALID_CREDENTIALS.__name__)
+    log.info(
+        'Bind case 2-2. the bind user\'s suffix does not exist, bind should fail with error %s' % ldap.INVALID_CREDENTIALS.__name__)
     log.info('Bind as {%s,%s} who does not exist.' % (BOGUSSUFFIX, 'bogus'))
-    try:
-        topology.standalone.simple_bind_s(BOGUSSUFFIX, 'bogus')
-    except ldap.LDAPError as e:
-        log.info("Exception (expected): %s" % type(e).__name__)
-        log.info('Desc ' + e.message['desc'])
-        assert isinstance(e, ldap.INVALID_CREDENTIALS)
-        regex = re.compile('No such suffix')
-        cause = pattern_accesslog(file_obj, regex)
-        if cause == None:
-            log.fatal('Cause not found - %s' % cause)
-            assert False
-        else:
-            log.info('Cause found - %s' % cause)
+    with pytest.raises(ldap.INVALID_CREDENTIALS):
+        topology_st.standalone.simple_bind_s(BOGUSSUFFIX, 'bogus')
+    regex = re.compile('No suffix for bind')
+    cause = pattern_accesslog(file_obj, regex)
+    if cause is None:
+        log.fatal('Cause not found - %s' % cause)
+        assert False
+    else:
+        log.info('Cause found - %s' % cause)
     time.sleep(1)
 
-    log.info('Bind case 2-3. the bind user\'s password is wrong, bind should fail with error %s' % ldap.INVALID_CREDENTIALS.__name__)
+    log.info(
+        'Bind case 2-3. the bind user\'s password is wrong, bind should fail with error %s' % ldap.INVALID_CREDENTIALS.__name__)
     log.info('Bind as {%s,%s} who does not exist.' % (BINDDN, 'bogus'))
     try:
-        topology.standalone.simple_bind_s(BINDDN, 'bogus')
+        topology_st.standalone.simple_bind_s(BINDDN, 'bogus')
     except ldap.LDAPError as e:
         log.info("Exception (expected): %s" % type(e).__name__)
         log.info('Desc ' + e.message['desc'])
         assert isinstance(e, ldap.INVALID_CREDENTIALS)
         regex = re.compile('Invalid credentials')
         cause = pattern_accesslog(file_obj, regex)
-        if cause == None:
+        if cause is None:
             log.fatal('Cause not found - %s' % cause)
             assert False
         else:
@@ -291,121 +249,139 @@ def test_ticket1347760(topology):
     acival = '(targetattr="*")(version 3.0; acl "%s"; allow(all) userdn = "ldap:///%s";)' % (BUID, BINDDN)
     log.info('aci: %s' % acival)
     log.info('Bind as {%s,%s}' % (DN_DM, PASSWORD))
-    topology.standalone.simple_bind_s(DN_DM, PASSWORD)
-    topology.standalone.modify_s(BINDOU, [(ldap.MOD_ADD, 'aci', acival)])
+    topology_st.standalone.simple_bind_s(DN_DM, PASSWORD)
+    topology_st.standalone.modify_s(BINDOU, [(ldap.MOD_ADD, 'aci', acival)])
     time.sleep(1)
 
     log.info('Bind case 3. the bind user has the right to read the entry itself, bind should be successful.')
     log.info('Bind as {%s,%s} which should be ok.\n' % (BINDDN, BINDPW))
-    topology.standalone.simple_bind_s(BINDDN, BINDPW)
+    topology_st.standalone.simple_bind_s(BINDDN, BINDPW)
 
     log.info('The following operations are against the subtree the bind user %s has no rights.' % BINDDN)
     # Search
     exists = True
     rc = ldap.SUCCESS
-    log.info('Search case 1. the bind user has no rights to read the search entry, it should return no search results with %s' % rc)
-    check_op_result(topology.standalone, 'search', TESTDN, None, exists, rc)
+    log.info(
+        'Search case 1. the bind user has no rights to read the search entry, it should return no search results with %s' % rc)
+    check_op_result(topology_st.standalone, 'search', TESTDN, None, exists, rc)
 
     exists = False
     rc = ldap.SUCCESS
-    log.info('Search case 2-1. the search entry does not exist, the search should return no search results with %s' % rc.__name__)
-    check_op_result(topology.standalone, 'search', BOGUSDN, None, exists, rc)
+    log.info(
+        'Search case 2-1. the search entry does not exist, the search should return no search results with %s' % rc.__name__)
+    check_op_result(topology_st.standalone, 'search', BOGUSDN, None, exists, rc)
 
     exists = False
     rc = ldap.SUCCESS
-    log.info('Search case 2-2. the search entry does not exist, the search should return no search results with %s' % rc.__name__)
-    check_op_result(topology.standalone, 'search', BOGUSDN2, None, exists, rc)
+    log.info(
+        'Search case 2-2. the search entry does not exist, the search should return no search results with %s' % rc.__name__)
+    check_op_result(topology_st.standalone, 'search', BOGUSDN2, None, exists, rc)
 
     # Add
     exists = True
     rc = ldap.INSUFFICIENT_ACCESS
-    log.info('Add case 1. the bind user has no rights AND the adding entry exists, it should fail with %s' % rc.__name__)
-    check_op_result(topology.standalone, 'add', TESTDN, None, exists, rc)
+    log.info(
+        'Add case 1. the bind user has no rights AND the adding entry exists, it should fail with %s' % rc.__name__)
+    check_op_result(topology_st.standalone, 'add', TESTDN, None, exists, rc)
 
     exists = False
     rc = ldap.INSUFFICIENT_ACCESS
-    log.info('Add case 2-1. the bind user has no rights AND the adding entry does not exist, it should fail with %s' % rc.__name__)
-    check_op_result(topology.standalone, 'add', BOGUSDN, None, exists, rc)
+    log.info(
+        'Add case 2-1. the bind user has no rights AND the adding entry does not exist, it should fail with %s' % rc.__name__)
+    check_op_result(topology_st.standalone, 'add', BOGUSDN, None, exists, rc)
 
     exists = False
     rc = ldap.INSUFFICIENT_ACCESS
-    log.info('Add case 2-2. the bind user has no rights AND the adding entry does not exist, it should fail with %s' % rc.__name__)
-    check_op_result(topology.standalone, 'add', BOGUSDN2, None, exists, rc)
+    log.info(
+        'Add case 2-2. the bind user has no rights AND the adding entry does not exist, it should fail with %s' % rc.__name__)
+    check_op_result(topology_st.standalone, 'add', BOGUSDN2, None, exists, rc)
 
     # Modify
     exists = True
     rc = ldap.INSUFFICIENT_ACCESS
-    log.info('Modify case 1. the bind user has no rights AND the modifying entry exists, it should fail with %s' % rc.__name__)
-    check_op_result(topology.standalone, 'modify', TESTDN, None, exists, rc)
+    log.info(
+        'Modify case 1. the bind user has no rights AND the modifying entry exists, it should fail with %s' % rc.__name__)
+    check_op_result(topology_st.standalone, 'modify', TESTDN, None, exists, rc)
 
     exists = False
     rc = ldap.INSUFFICIENT_ACCESS
-    log.info('Modify case 2-1. the bind user has no rights AND the modifying entry does not exist, it should fail with %s' % rc.__name__)
-    check_op_result(topology.standalone, 'modify', BOGUSDN, None, exists, rc)
+    log.info(
+        'Modify case 2-1. the bind user has no rights AND the modifying entry does not exist, it should fail with %s' % rc.__name__)
+    check_op_result(topology_st.standalone, 'modify', BOGUSDN, None, exists, rc)
 
     exists = False
     rc = ldap.INSUFFICIENT_ACCESS
-    log.info('Modify case 2-2. the bind user has no rights AND the modifying entry does not exist, it should fail with %s' % rc.__name__)
-    check_op_result(topology.standalone, 'modify', BOGUSDN2, None, exists, rc)
+    log.info(
+        'Modify case 2-2. the bind user has no rights AND the modifying entry does not exist, it should fail with %s' % rc.__name__)
+    check_op_result(topology_st.standalone, 'modify', BOGUSDN2, None, exists, rc)
 
     # Modrdn
     exists = True
     rc = ldap.INSUFFICIENT_ACCESS
-    log.info('Modrdn case 1. the bind user has no rights AND the renaming entry exists, it should fail with %s' % rc.__name__)
-    check_op_result(topology.standalone, 'modrdn', TESTDN, None, exists, rc)
+    log.info(
+        'Modrdn case 1. the bind user has no rights AND the renaming entry exists, it should fail with %s' % rc.__name__)
+    check_op_result(topology_st.standalone, 'modrdn', TESTDN, None, exists, rc)
 
     exists = False
     rc = ldap.INSUFFICIENT_ACCESS
-    log.info('Modrdn case 2-1. the bind user has no rights AND the renaming entry does not exist, it should fail with %s' % rc.__name__)
-    check_op_result(topology.standalone, 'modrdn', BOGUSDN, None, exists, rc)
+    log.info(
+        'Modrdn case 2-1. the bind user has no rights AND the renaming entry does not exist, it should fail with %s' % rc.__name__)
+    check_op_result(topology_st.standalone, 'modrdn', BOGUSDN, None, exists, rc)
 
     exists = False
     rc = ldap.INSUFFICIENT_ACCESS
-    log.info('Modrdn case 2-2. the bind user has no rights AND the renaming entry does not exist, it should fail with %s' % rc.__name__)
-    check_op_result(topology.standalone, 'modrdn', BOGUSDN2, None, exists, rc)
+    log.info(
+        'Modrdn case 2-2. the bind user has no rights AND the renaming entry does not exist, it should fail with %s' % rc.__name__)
+    check_op_result(topology_st.standalone, 'modrdn', BOGUSDN2, None, exists, rc)
 
     exists = True
     rc = ldap.INSUFFICIENT_ACCESS
-    log.info('Modrdn case 3. the bind user has no rights AND the node moving an entry to exists, it should fail with %s' % rc.__name__)
-    check_op_result(topology.standalone, 'modrdn', TESTDN, GROUPOU, exists, rc)
+    log.info(
+        'Modrdn case 3. the bind user has no rights AND the node moving an entry to exists, it should fail with %s' % rc.__name__)
+    check_op_result(topology_st.standalone, 'modrdn', TESTDN, GROUPOU, exists, rc)
 
     exists = False
     rc = ldap.INSUFFICIENT_ACCESS
-    log.info('Modrdn case 4-1. the bind user has no rights AND the node moving an entry to does not, it should fail with %s' % rc.__name__)
-    check_op_result(topology.standalone, 'modrdn', TESTDN, BOGUSOU, exists, rc)
+    log.info(
+        'Modrdn case 4-1. the bind user has no rights AND the node moving an entry to does not, it should fail with %s' % rc.__name__)
+    check_op_result(topology_st.standalone, 'modrdn', TESTDN, BOGUSOU, exists, rc)
 
     exists = False
     rc = ldap.INSUFFICIENT_ACCESS
-    log.info('Modrdn case 4-2. the bind user has no rights AND the node moving an entry to does not, it should fail with %s' % rc.__name__)
-    check_op_result(topology.standalone, 'modrdn', TESTDN, BOGUSOU, exists, rc)
+    log.info(
+        'Modrdn case 4-2. the bind user has no rights AND the node moving an entry to does not, it should fail with %s' % rc.__name__)
+    check_op_result(topology_st.standalone, 'modrdn', TESTDN, BOGUSOU, exists, rc)
 
     # Delete
     exists = True
     rc = ldap.INSUFFICIENT_ACCESS
-    log.info('Delete case 1. the bind user has no rights AND the deleting entry exists, it should fail with %s' % rc.__name__)
-    check_op_result(topology.standalone, 'delete', TESTDN, None, exists, rc)
+    log.info(
+        'Delete case 1. the bind user has no rights AND the deleting entry exists, it should fail with %s' % rc.__name__)
+    check_op_result(topology_st.standalone, 'delete', TESTDN, None, exists, rc)
 
     exists = False
     rc = ldap.INSUFFICIENT_ACCESS
-    log.info('Delete case 2-1. the bind user has no rights AND the deleting entry does not exist, it should fail with %s' % rc.__name__)
-    check_op_result(topology.standalone, 'delete', BOGUSDN, None, exists, rc)
+    log.info(
+        'Delete case 2-1. the bind user has no rights AND the deleting entry does not exist, it should fail with %s' % rc.__name__)
+    check_op_result(topology_st.standalone, 'delete', BOGUSDN, None, exists, rc)
 
     exists = False
     rc = ldap.INSUFFICIENT_ACCESS
-    log.info('Delete case 2-2. the bind user has no rights AND the deleting entry does not exist, it should fail with %s' % rc.__name__)
-    check_op_result(topology.standalone, 'delete', BOGUSDN2, None, exists, rc)
+    log.info(
+        'Delete case 2-2. the bind user has no rights AND the deleting entry does not exist, it should fail with %s' % rc.__name__)
+    check_op_result(topology_st.standalone, 'delete', BOGUSDN2, None, exists, rc)
 
     log.info('EXTRA: Check no regressions')
     log.info('Adding aci for %s to %s.' % (BINDDN, DEFAULT_SUFFIX))
     acival = '(targetattr="*")(version 3.0; acl "%s-all"; allow(all) userdn = "ldap:///%s";)' % (BUID, BINDDN)
     log.info('Bind as {%s,%s}' % (DN_DM, PASSWORD))
-    topology.standalone.simple_bind_s(DN_DM, PASSWORD)
-    topology.standalone.modify_s(DEFAULT_SUFFIX, [(ldap.MOD_ADD, 'aci', acival)])
+    topology_st.standalone.simple_bind_s(DN_DM, PASSWORD)
+    topology_st.standalone.modify_s(DEFAULT_SUFFIX, [(ldap.MOD_ADD, 'aci', acival)])
     time.sleep(1)
 
     log.info('Bind as {%s,%s}.' % (BINDDN, BINDPW))
     try:
-        topology.standalone.simple_bind_s(BINDDN, BINDPW)
+        topology_st.standalone.simple_bind_s(BINDDN, BINDPW)
     except ldap.LDAPError as e:
         log.info('Desc ' + e.message['desc'])
         assert False
@@ -414,54 +390,60 @@ def test_ticket1347760(topology):
     exists = False
     rc = ldap.NO_SUCH_OBJECT
     log.info('Search case. the search entry does not exist, the search should fail with %s' % rc.__name__)
-    check_op_result(topology.standalone, 'search', BOGUSDN2, None, exists, rc)
+    check_op_result(topology_st.standalone, 'search', BOGUSDN2, None, exists, rc)
     file_obj.close()
 
     exists = True
     rc = ldap.ALREADY_EXISTS
     log.info('Add case. the adding entry already exists, it should fail with %s' % rc.__name__)
-    check_op_result(topology.standalone, 'add', TESTDN, None, exists, rc)
+    check_op_result(topology_st.standalone, 'add', TESTDN, None, exists, rc)
 
     exists = False
     rc = ldap.NO_SUCH_OBJECT
     log.info('Modify case. the modifying entry does not exist, it should fail with %s' % rc.__name__)
-    check_op_result(topology.standalone, 'modify', BOGUSDN, None, exists, rc)
+    check_op_result(topology_st.standalone, 'modify', BOGUSDN, None, exists, rc)
 
     exists = False
     rc = ldap.NO_SUCH_OBJECT
     log.info('Modrdn case 1. the renaming entry does not exist, it should fail with %s' % rc.__name__)
-    check_op_result(topology.standalone, 'modrdn', BOGUSDN, None, exists, rc)
+    check_op_result(topology_st.standalone, 'modrdn', BOGUSDN, None, exists, rc)
 
     exists = False
     rc = ldap.NO_SUCH_OBJECT
     log.info('Modrdn case 2. the node moving an entry to does not, it should fail with %s' % rc.__name__)
-    check_op_result(topology.standalone, 'modrdn', TESTDN, BOGUSOU, exists, rc)
+    check_op_result(topology_st.standalone, 'modrdn', TESTDN, BOGUSOU, exists, rc)
 
     exists = False
     rc = ldap.NO_SUCH_OBJECT
     log.info('Delete case. the deleting entry does not exist, it should fail with %s' % rc.__name__)
-    check_op_result(topology.standalone, 'delete', BOGUSDN, None, exists, rc)
+    check_op_result(topology_st.standalone, 'delete', BOGUSDN, None, exists, rc)
 
     log.info('Inactivate %s' % BINDDN)
-    nsinactivate = '%s/sbin/ns-inactivate.pl' % topology.standalone.prefix
-    p = Popen([nsinactivate, '-Z', 'standalone', '-D', DN_DM, '-w', PASSWORD, '-I', BINDDN])
-    assert(p.wait() == 0)
+    if ds_paths.version < '1.3':
+        nsinactivate = '%s/ns-inactivate.pl' % inst_dir
+        nsinactivate_cmd = [nsinactivate, '-D', DN_DM, '-w', PASSWORD, '-I', BINDDN]
+    else:
+        nsinactivate = '%s/ns-inactivate.pl' % ds_paths.sbin_dir
+        nsinactivate_cmd = [nsinactivate, '-Z', SERVERID_STANDALONE, '-D', DN_DM, '-w', PASSWORD, '-I', BINDDN]
+    log.info(nsinactivate_cmd)
+    p = Popen(nsinactivate_cmd)
+    assert (p.wait() == 0)
 
     log.info('Bind as {%s,%s} which should fail with %s.' % (BINDDN, BUID, ldap.UNWILLING_TO_PERFORM.__name__))
     try:
-        topology.standalone.simple_bind_s(BINDDN, BUID)
+        topology_st.standalone.simple_bind_s(BINDDN, BUID)
     except ldap.LDAPError as e:
         log.info("Exception (expected): %s" % type(e).__name__)
         log.info('Desc ' + e.message['desc'])
         assert isinstance(e, ldap.UNWILLING_TO_PERFORM)
 
-    log.info('Bind as {%s,%s} which should fail with %s.' % (BINDDN, 'bogus', ldap.INVALID_CREDENTIALS.__name__))
+    log.info('Bind as {%s,%s} which should fail with %s.' % (BINDDN, 'bogus', ldap.UNWILLING_TO_PERFORM.__name__))
     try:
-        topology.standalone.simple_bind_s(BINDDN, 'bogus')
+        topology_st.standalone.simple_bind_s(BINDDN, 'bogus')
     except ldap.LDAPError as e:
         log.info("Exception (expected): %s" % type(e).__name__)
         log.info('Desc ' + e.message['desc'])
-        assert isinstance(e, ldap.INVALID_CREDENTIALS)
+        assert isinstance(e, ldap.UNWILLING_TO_PERFORM)
 
     log.info('SUCCESS')
 
