@@ -1,5 +1,5 @@
 # --- BEGIN COPYRIGHT BLOCK ---
-# Copyright (C) 2015 Red Hat, Inc.
+# Copyright (C) 2016 Red Hat, Inc.
 # All rights reserved.
 #
 # License: GPL (version 3 or any later version).
@@ -11,45 +11,37 @@ Created on Nov 7, 2013
 
 @author: tbordaz
 '''
-import os
-import sys
-import ldap
-import time
 import logging
-import pytest
 import re
-from lib389 import DirSrv, Entry
-from lib389._constants import *
-from lib389.properties import *
+import time
 
+import ldap
+import pytest
+from lib389 import Entry
+from lib389._constants import *
+from lib389.topologies import topology_m1c1
+
+from lib389.utils import *
+
+# Skip on older versions
+pytestmark = pytest.mark.skipif(ds_is_older('1.3'), reason="Not implemented")
 logging.getLogger(__name__).setLevel(logging.DEBUG)
 log = logging.getLogger(__name__)
 
-installation_prefix = None
-
 TEST_REPL_DN = "cn=test_repl, %s" % SUFFIX
 ENTRY_DN = "cn=test_entry, %s" % SUFFIX
 MUST_OLD = "(postalAddress $ preferredLocale)"
 MUST_NEW = "(postalAddress $ preferredLocale $ telexNumber)"
-MAY_OLD  = "(postalCode $ street)"
-MAY_NEW  = "(postalCode $ street $ postOfficeBox)"
+MAY_OLD = "(postalCode $ street)"
+MAY_NEW = "(postalCode $ street $ postOfficeBox)"
 
 
-class TopologyMasterConsumer(object):
-    def __init__(self, master, consumer):
-        master.open()
-        self.master = master
-
-        consumer.open()
-        self.consumer = consumer
-
-
-def _header(topology, label):
-    topology.master.log.info("\n\n###############################################")
-    topology.master.log.info("#######")
-    topology.master.log.info("####### %s" % label)
-    topology.master.log.info("#######")
-    topology.master.log.info("###################################################")
+def _header(topology_m1c1, label):
+    topology_m1c1.ms["master1"].log.info("\n\n###############################################")
+    topology_m1c1.ms["master1"].log.info("#######")
+    topology_m1c1.ms["master1"].log.info("####### %s" % label)
+    topology_m1c1.ms["master1"].log.info("#######")
+    topology_m1c1.ms["master1"].log.info("###################################################")
 
 
 def pattern_errorlog(file, log_pattern):
@@ -77,9 +69,9 @@ def pattern_errorlog(file, log_pattern):
 
 
 def _oc_definition(oid_ext, name, must=None, may=None):
-    oid  = "1.2.3.4.5.6.7.8.9.10.%d" % oid_ext
+    oid = "1.2.3.4.5.6.7.8.9.10.%d" % oid_ext
     desc = 'To test ticket 47490'
-    sup  = 'person'
+    sup = 'person'
     if not must:
         must = MUST_OLD
     if not may:
@@ -101,7 +93,7 @@ def mod_OC(instance, oid_ext, name, old_must=None, old_may=None, new_must=None,
     instance.schema.add_schema('objectClasses', new_oc)
 
 
-def support_schema_learning(topology):
+def support_schema_learning(topology_m1c1):
     """
     with https://fedorahosted.org/389/ticket/47721, the supplier and consumer can learn
     schema definitions when a replication occurs.
@@ -114,7 +106,7 @@ def support_schema_learning(topology):
     This function returns True if 47721 is fixed in the current release
     False else
     """
-    ent = topology.consumer.getEntry(DN_CONFIG, ldap.SCOPE_BASE, "(cn=config)", ['nsslapd-versionstring'])
+    ent = topology_m1c1.cs["consumer1"].getEntry(DN_CONFIG, ldap.SCOPE_BASE, "(cn=config)", ['nsslapd-versionstring'])
     if ent.hasAttr('nsslapd-versionstring'):
         val = ent.getValue('nsslapd-versionstring')
         version = val.split('/')[1].split('.')  # something like ['1', '3', '1', '23', 'final_fix']
@@ -132,7 +124,7 @@ def support_schema_learning(topology):
         return False
 
 
-def trigger_update(topology):
+def trigger_update(topology_m1c1):
     """
         It triggers an update on the supplier. This will start a replication
         session and a schema push
@@ -142,13 +134,14 @@ def trigger_update(topology):
     except AttributeError:
         trigger_update.value = 1
     replace = [(ldap.MOD_REPLACE, 'telephonenumber', str(trigger_update.value))]
-    topology.master.modify_s(ENTRY_DN, replace)
+    topology_m1c1.ms["master1"].modify_s(ENTRY_DN, replace)
 
     # wait 10 seconds that the update is replicated
     loop = 0
     while loop <= 10:
         try:
-            ent = topology.consumer.getEntry(ENTRY_DN, ldap.SCOPE_BASE, "(objectclass=*)", ['telephonenumber'])
+            ent = topology_m1c1.cs["consumer1"].getEntry(ENTRY_DN, ldap.SCOPE_BASE, "(objectclass=*)",
+                                                         ['telephonenumber'])
             val = ent.telephonenumber or "0"
             if int(val) == trigger_update.value:
                 return
@@ -161,7 +154,7 @@ def trigger_update(topology):
             loop += 1
 
 
-def trigger_schema_push(topology):
+def trigger_schema_push(topology_m1c1):
     '''
     Trigger update to create a replication session.
     In case of 47721 is fixed and the replica needs to learn the missing definition, then
@@ -169,116 +162,35 @@ def trigger_schema_push(topology):
     push the schema (and the schemaCSN.
     This is why there is two updates and replica agreement is stopped/start (to create a second session)
     '''
-    agreements = topology.master.agreement.list(suffix=SUFFIX, consumer_host=topology.consumer.host, consumer_port=topology.consumer.port)
-    assert(len(agreements) == 1)
+    agreements = topology_m1c1.ms["master1"].agreement.list(suffix=SUFFIX,
+                                                            consumer_host=topology_m1c1.cs["consumer1"].host,
+                                                            consumer_port=topology_m1c1.cs["consumer1"].port)
+    assert (len(agreements) == 1)
     ra = agreements[0]
-    trigger_update(topology)
-    topology.master.agreement.pause(ra.dn)
-    topology.master.agreement.resume(ra.dn)
-    trigger_update(topology)
+    trigger_update(topology_m1c1)
+    topology_m1c1.ms["master1"].agreement.pause(ra.dn)
+    topology_m1c1.ms["master1"].agreement.resume(ra.dn)
+    trigger_update(topology_m1c1)
 
 
-@pytest.fixture(scope="module")
-def topology(request):
-    '''
-        This fixture is used to create a replicated topology for the 'module'.
-        The replicated topology is MASTER -> Consumer.
-    '''
-    global installation_prefix
-
-    if installation_prefix:
-        args_instance[SER_DEPLOYED_DIR] = installation_prefix
-
-    master   = DirSrv(verbose=False)
-    consumer = DirSrv(verbose=False)
-
-    # Args for the master instance
-    args_instance[SER_HOST] = HOST_MASTER_1
-    args_instance[SER_PORT] = PORT_MASTER_1
-    args_instance[SER_SERVERID_PROP] = SERVERID_MASTER_1
-    args_master = args_instance.copy()
-    master.allocate(args_master)
-
-    # Args for the consumer instance
-    args_instance[SER_HOST] = HOST_CONSUMER_1
-    args_instance[SER_PORT] = PORT_CONSUMER_1
-    args_instance[SER_SERVERID_PROP] = SERVERID_CONSUMER_1
-    args_consumer = args_instance.copy()
-    consumer.allocate(args_consumer)
-
-    # Get the status of the instance
-    instance_master = master.exists()
-    instance_consumer = consumer.exists()
-
-    # Remove all the instances
-    if instance_master:
-        master.delete()
-    if instance_consumer:
-        consumer.delete()
-
-    # Create the instances
-    master.create()
-    master.open()
-    consumer.create()
-    consumer.open()
-
-    #
-    # Now prepare the Master-Consumer topology
-    #
-    # First Enable replication
-    master.replica.enableReplication(suffix=SUFFIX, role=REPLICAROLE_MASTER, replicaId=REPLICAID_MASTER_1)
-    consumer.replica.enableReplication(suffix=SUFFIX, role=REPLICAROLE_CONSUMER)
-
-    # Initialize the supplier->consumer
-    properties = {RA_NAME:      r'meTo_$host:$port',
-                  RA_BINDDN:    defaultProperties[REPLICATION_BIND_DN],
-                  RA_BINDPW:    defaultProperties[REPLICATION_BIND_PW],
-                  RA_METHOD:    defaultProperties[REPLICATION_BIND_METHOD],
-                  RA_TRANSPORT_PROT: defaultProperties[REPLICATION_TRANSPORT]}
-    repl_agreement = master.agreement.create(suffix=SUFFIX, host=consumer.host, port=consumer.port, properties=properties)
-
-    if not repl_agreement:
-        log.fatal("Fail to create a replica agreement")
-        sys.exit(1)
-
-    log.debug("%s created" % repl_agreement)
-    master.agreement.init(SUFFIX, HOST_CONSUMER_1, PORT_CONSUMER_1)
-    master.waitForReplInit(repl_agreement)
-
-    # Check replication is working fine
-    if master.testReplication(DEFAULT_SUFFIX, consumer):
-        log.info('Replication is working.')
-    else:
-        log.fatal('Replication is not working.')
-        assert False
-
-    def fin():
-        master.delete()
-        consumer.delete()
-    request.addfinalizer(fin)
-    #
-    # Here we have two instances master and consumer
-    # with replication working.
-    return TopologyMasterConsumer(master, consumer)
-
-
-def test_ticket47490_init(topology):
+def test_ticket47490_init(topology_m1c1):
     """
         Initialize the test environment
     """
-    log.debug("test_ticket47490_init topology %r (master %r, consumer %r" % (topology, topology.master, topology.consumer))
+    log.debug("test_ticket47490_init topology_m1c1 %r (master %r, consumer %r" % (
+    topology_m1c1, topology_m1c1.ms["master1"], topology_m1c1.cs["consumer1"]))
     # the test case will check if a warning message is logged in the
     # error log of the supplier
-    topology.master.errorlog_file = open(topology.master.errlog, "r")
+    topology_m1c1.ms["master1"].errorlog_file = open(topology_m1c1.ms["master1"].errlog, "r")
 
     # This entry will be used to trigger attempt of schema push
-    topology.master.add_s(Entry((ENTRY_DN, {
-                                            'objectclass': "top person".split(),
-                                            'sn': 'test_entry',
-                                            'cn': 'test_entry'})))
+    topology_m1c1.ms["master1"].add_s(Entry((ENTRY_DN, {
+        'objectclass': "top person".split(),
+        'sn': 'test_entry',
+        'cn': 'test_entry'})))
 
 
-def test_ticket47490_one(topology):
+def test_ticket47490_one(topology_m1c1):
     """
         Summary: Extra OC Schema is pushed - no error
 
@@ -292,16 +204,17 @@ def test_ticket47490_one(topology):
             - consumer +masterNewOCA
 
     """
-    _header(topology, "Extra OC Schema is pushed - no error")
+    _header(topology_m1c1, "Extra OC Schema is pushed - no error")
 
-    log.debug("test_ticket47490_one topology %r (master %r, consumer %r" % (topology, topology.master, topology.consumer))
+    log.debug("test_ticket47490_one topology_m1c1 %r (master %r, consumer %r" % (
+    topology_m1c1, topology_m1c1.ms["master1"], topology_m1c1.cs["consumer1"]))
     # update the schema of the supplier so that it is a superset of
     # consumer. Schema should be pushed
-    add_OC(topology.master, 2, 'masterNewOCA')
+    add_OC(topology_m1c1.ms["master1"], 2, 'masterNewOCA')
 
-    trigger_schema_push(topology)
-    master_schema_csn = topology.master.schema.get_schema_csn()
-    consumer_schema_csn = topology.consumer.schema.get_schema_csn()
+    trigger_schema_push(topology_m1c1)
+    master_schema_csn = topology_m1c1.ms["master1"].schema.get_schema_csn()
+    consumer_schema_csn = topology_m1c1.cs["consumer1"].schema.get_schema_csn()
 
     # Check the schemaCSN was updated on the consumer
     log.debug("test_ticket47490_one master_schema_csn=%s", master_schema_csn)
@@ -310,12 +223,12 @@ def test_ticket47490_one(topology):
 
     # Check the error log of the supplier does not contain an error
     regex = re.compile("must not be overwritten \(set replication log for additional info\)")
-    res = pattern_errorlog(topology.master.errorlog_file, regex)
+    res = pattern_errorlog(topology_m1c1.ms["master1"].errorlog_file, regex)
     if res is not None:
         assert False
 
 
-def test_ticket47490_two(topology):
+def test_ticket47490_two(topology_m1c1):
     """
         Summary: Extra OC Schema is pushed - (ticket 47721 allows to learn missing def)
 
@@ -330,25 +243,25 @@ def test_ticket47490_two(topology):
 
     """
 
-    _header(topology, "Extra OC Schema is pushed - (ticket 47721 allows to learn missing def)")
+    _header(topology_m1c1, "Extra OC Schema is pushed - (ticket 47721 allows to learn missing def)")
 
     # add this OC on consumer. Supplier will no push the schema
-    add_OC(topology.consumer, 1, 'consumerNewOCA')
+    add_OC(topology_m1c1.cs["consumer1"], 1, 'consumerNewOCA')
 
     # add a new OC on the supplier so that its nsSchemaCSN is larger than the consumer (wait 2s)
     time.sleep(2)
-    add_OC(topology.master, 3, 'masterNewOCB')
+    add_OC(topology_m1c1.ms["master1"], 3, 'masterNewOCB')
 
     # now push the scheam
-    trigger_schema_push(topology)
-    master_schema_csn = topology.master.schema.get_schema_csn()
-    consumer_schema_csn = topology.consumer.schema.get_schema_csn()
+    trigger_schema_push(topology_m1c1)
+    master_schema_csn = topology_m1c1.ms["master1"].schema.get_schema_csn()
+    consumer_schema_csn = topology_m1c1.cs["consumer1"].schema.get_schema_csn()
 
     # Check the schemaCSN was NOT updated on the consumer
     # with 47721, supplier learns the missing definition
     log.debug("test_ticket47490_two master_schema_csn=%s", master_schema_csn)
     log.debug("test_ticket47490_two consumer_schema_csn=%s", consumer_schema_csn)
-    if support_schema_learning(topology):
+    if support_schema_learning(topology_m1c1):
         assert master_schema_csn == consumer_schema_csn
     else:
         assert master_schema_csn != consumer_schema_csn
@@ -356,10 +269,10 @@ def test_ticket47490_two(topology):
     # Check the error log of the supplier does not contain an error
     # This message may happen during the learning phase
     regex = re.compile("must not be overwritten \(set replication log for additional info\)")
-    res = pattern_errorlog(topology.master.errorlog_file, regex)
+    res = pattern_errorlog(topology_m1c1.ms["master1"].errorlog_file, regex)
 
 
-def test_ticket47490_three(topology):
+def test_ticket47490_three(topology_m1c1):
     """
         Summary: Extra OC Schema is pushed - no error
 
@@ -373,16 +286,16 @@ def test_ticket47490_three(topology):
             - consumer +masterNewOCA +masterNewOCB +consumerNewOCA
 
     """
-    _header(topology, "Extra OC Schema is pushed - no error")
+    _header(topology_m1c1, "Extra OC Schema is pushed - no error")
 
     # Do an upate to trigger the schema push attempt
     # add this OC on consumer. Supplier will no push the schema
-    add_OC(topology.master, 1, 'consumerNewOCA')
+    add_OC(topology_m1c1.ms["master1"], 1, 'consumerNewOCA')
 
     # now push the scheam
-    trigger_schema_push(topology)
-    master_schema_csn = topology.master.schema.get_schema_csn()
-    consumer_schema_csn = topology.consumer.schema.get_schema_csn()
+    trigger_schema_push(topology_m1c1)
+    master_schema_csn = topology_m1c1.ms["master1"].schema.get_schema_csn()
+    consumer_schema_csn = topology_m1c1.cs["consumer1"].schema.get_schema_csn()
 
     # Check the schemaCSN was NOT updated on the consumer
     log.debug("test_ticket47490_three master_schema_csn=%s", master_schema_csn)
@@ -391,12 +304,12 @@ def test_ticket47490_three(topology):
 
     # Check the error log of the supplier does not contain an error
     regex = re.compile("must not be overwritten \(set replication log for additional info\)")
-    res = pattern_errorlog(topology.master.errorlog_file, regex)
+    res = pattern_errorlog(topology_m1c1.ms["master1"].errorlog_file, regex)
     if res is not None:
         assert False
 
 
-def test_ticket47490_four(topology):
+def test_ticket47490_four(topology_m1c1):
     """
         Summary: Same OC - extra MUST: Schema is pushed - no error
 
@@ -412,13 +325,14 @@ def test_ticket47490_four(topology):
                        +must=telexnumber
 
     """
-    _header(topology, "Same OC - extra MUST: Schema is pushed - no error")
+    _header(topology_m1c1, "Same OC - extra MUST: Schema is pushed - no error")
 
-    mod_OC(topology.master, 2, 'masterNewOCA', old_must=MUST_OLD, new_must=MUST_NEW, old_may=MAY_OLD, new_may=MAY_OLD)
+    mod_OC(topology_m1c1.ms["master1"], 2, 'masterNewOCA', old_must=MUST_OLD, new_must=MUST_NEW, old_may=MAY_OLD,
+           new_may=MAY_OLD)
 
-    trigger_schema_push(topology)
-    master_schema_csn = topology.master.schema.get_schema_csn()
-    consumer_schema_csn = topology.consumer.schema.get_schema_csn()
+    trigger_schema_push(topology_m1c1)
+    master_schema_csn = topology_m1c1.ms["master1"].schema.get_schema_csn()
+    consumer_schema_csn = topology_m1c1.cs["consumer1"].schema.get_schema_csn()
 
     # Check the schemaCSN was updated on the consumer
     log.debug("test_ticket47490_four master_schema_csn=%s", master_schema_csn)
@@ -427,12 +341,12 @@ def test_ticket47490_four(topology):
 
     # Check the error log of the supplier does not contain an error
     regex = re.compile("must not be overwritten \(set replication log for additional info\)")
-    res = pattern_errorlog(topology.master.errorlog_file, regex)
+    res = pattern_errorlog(topology_m1c1.ms["master1"].errorlog_file, regex)
     if res is not None:
         assert False
 
 
-def test_ticket47490_five(topology):
+def test_ticket47490_five(topology_m1c1):
     """
         Summary: Same OC - extra MUST: Schema is pushed - (fix for 47721)
 
@@ -451,26 +365,27 @@ def test_ticket47490_five(topology):
 
         Note: replication log is enabled to get more details
     """
-    _header(topology, "Same OC - extra MUST: Schema is pushed - (fix for 47721)")
+    _header(topology_m1c1, "Same OC - extra MUST: Schema is pushed - (fix for 47721)")
 
     # get more detail why it fails
-    topology.master.enableReplLogging()
+    topology_m1c1.ms["master1"].enableReplLogging()
 
     # add telenumber to 'consumerNewOCA' on the consumer
-    mod_OC(topology.consumer, 1, 'consumerNewOCA', old_must=MUST_OLD, new_must=MUST_NEW, old_may=MAY_OLD, new_may=MAY_OLD)
+    mod_OC(topology_m1c1.cs["consumer1"], 1, 'consumerNewOCA', old_must=MUST_OLD, new_must=MUST_NEW, old_may=MAY_OLD,
+           new_may=MAY_OLD)
     # add a new OC on the supplier so that its nsSchemaCSN is larger than the consumer (wait 2s)
     time.sleep(2)
-    add_OC(topology.master, 4, 'masterNewOCC')
+    add_OC(topology_m1c1.ms["master1"], 4, 'masterNewOCC')
 
-    trigger_schema_push(topology)
-    master_schema_csn = topology.master.schema.get_schema_csn()
-    consumer_schema_csn = topology.consumer.schema.get_schema_csn()
+    trigger_schema_push(topology_m1c1)
+    master_schema_csn = topology_m1c1.ms["master1"].schema.get_schema_csn()
+    consumer_schema_csn = topology_m1c1.cs["consumer1"].schema.get_schema_csn()
 
     # Check the schemaCSN was NOT updated on the consumer
     # with 47721, supplier learns the missing definition
     log.debug("test_ticket47490_five master_schema_csn=%s", master_schema_csn)
     log.debug("ctest_ticket47490_five onsumer_schema_csn=%s", consumer_schema_csn)
-    if support_schema_learning(topology):
+    if support_schema_learning(topology_m1c1):
         assert master_schema_csn == consumer_schema_csn
     else:
         assert master_schema_csn != consumer_schema_csn
@@ -478,10 +393,10 @@ def test_ticket47490_five(topology):
     # Check the error log of the supplier does not contain an error
     # This message may happen during the learning phase
     regex = re.compile("must not be overwritten \(set replication log for additional info\)")
-    res = pattern_errorlog(topology.master.errorlog_file, regex)
+    res = pattern_errorlog(topology_m1c1.ms["master1"].errorlog_file, regex)
 
 
-def test_ticket47490_six(topology):
+def test_ticket47490_six(topology_m1c1):
     """
         Summary: Same OC - extra MUST: Schema is pushed - no error
 
@@ -501,14 +416,15 @@ def test_ticket47490_six(topology):
 
         Note: replication log is enabled to get more details
     """
-    _header(topology, "Same OC - extra MUST: Schema is pushed - no error")
+    _header(topology_m1c1, "Same OC - extra MUST: Schema is pushed - no error")
 
     # add telenumber to 'consumerNewOCA' on the consumer
-    mod_OC(topology.master, 1, 'consumerNewOCA', old_must=MUST_OLD, new_must=MUST_NEW, old_may=MAY_OLD, new_may=MAY_OLD)
+    mod_OC(topology_m1c1.ms["master1"], 1, 'consumerNewOCA', old_must=MUST_OLD, new_must=MUST_NEW, old_may=MAY_OLD,
+           new_may=MAY_OLD)
 
-    trigger_schema_push(topology)
-    master_schema_csn = topology.master.schema.get_schema_csn()
-    consumer_schema_csn = topology.consumer.schema.get_schema_csn()
+    trigger_schema_push(topology_m1c1)
+    master_schema_csn = topology_m1c1.ms["master1"].schema.get_schema_csn()
+    consumer_schema_csn = topology_m1c1.cs["consumer1"].schema.get_schema_csn()
 
     # Check the schemaCSN was NOT updated on the consumer
     log.debug("test_ticket47490_six master_schema_csn=%s", master_schema_csn)
@@ -518,12 +434,12 @@ def test_ticket47490_six(topology):
     # Check the error log of the supplier does not contain an error
     # This message may happen during the learning phase
     regex = re.compile("must not be overwritten \(set replication log for additional info\)")
-    res = pattern_errorlog(topology.master.errorlog_file, regex)
+    res = pattern_errorlog(topology_m1c1.ms["master1"].errorlog_file, regex)
     if res is not None:
         assert False
 
 
-def test_ticket47490_seven(topology):
+def test_ticket47490_seven(topology_m1c1):
     """
         Summary: Same OC - extra MAY: Schema is pushed - no error
 
@@ -542,13 +458,14 @@ def test_ticket47490_seven(topology):
                        +must=telexnumber                   +must=telexnumber
                        +may=postOfficeBox
     """
-    _header(topology, "Same OC - extra MAY: Schema is pushed - no error")
+    _header(topology_m1c1, "Same OC - extra MAY: Schema is pushed - no error")
 
-    mod_OC(topology.master, 2, 'masterNewOCA', old_must=MUST_NEW, new_must=MUST_NEW, old_may=MAY_OLD, new_may=MAY_NEW)
+    mod_OC(topology_m1c1.ms["master1"], 2, 'masterNewOCA', old_must=MUST_NEW, new_must=MUST_NEW, old_may=MAY_OLD,
+           new_may=MAY_NEW)
 
-    trigger_schema_push(topology)
-    master_schema_csn = topology.master.schema.get_schema_csn()
-    consumer_schema_csn = topology.consumer.schema.get_schema_csn()
+    trigger_schema_push(topology_m1c1)
+    master_schema_csn = topology_m1c1.ms["master1"].schema.get_schema_csn()
+    consumer_schema_csn = topology_m1c1.cs["consumer1"].schema.get_schema_csn()
 
     # Check the schemaCSN was updated on the consumer
     log.debug("test_ticket47490_seven master_schema_csn=%s", master_schema_csn)
@@ -557,12 +474,12 @@ def test_ticket47490_seven(topology):
 
     # Check the error log of the supplier does not contain an error
     regex = re.compile("must not be overwritten \(set replication log for additional info\)")
-    res = pattern_errorlog(topology.master.errorlog_file, regex)
+    res = pattern_errorlog(topology_m1c1.ms["master1"].errorlog_file, regex)
     if res is not None:
         assert False
 
 
-def test_ticket47490_eight(topology):
+def test_ticket47490_eight(topology_m1c1):
     """
         Summary: Same OC - extra MAY: Schema is pushed (fix for 47721)
 
@@ -583,23 +500,25 @@ def test_ticket47490_eight(topology):
                        +must=telexnumber                   +must=telexnumber
                        +may=postOfficeBox                  +may=postOfficeBox
     """
-    _header(topology, "Same OC - extra MAY: Schema is pushed (fix for 47721)")
+    _header(topology_m1c1, "Same OC - extra MAY: Schema is pushed (fix for 47721)")
 
-    mod_OC(topology.consumer, 1, 'consumerNewOCA', old_must=MUST_NEW, new_must=MUST_NEW, old_may=MAY_OLD, new_may=MAY_NEW)
+    mod_OC(topology_m1c1.cs["consumer1"], 1, 'consumerNewOCA', old_must=MUST_NEW, new_must=MUST_NEW, old_may=MAY_OLD,
+           new_may=MAY_NEW)
 
     # modify OC on the supplier so that its nsSchemaCSN is larger than the consumer (wait 2s)
     time.sleep(2)
-    mod_OC(topology.master, 4, 'masterNewOCC', old_must=MUST_OLD, new_must=MUST_OLD, old_may=MAY_OLD, new_may=MAY_NEW)
+    mod_OC(topology_m1c1.ms["master1"], 4, 'masterNewOCC', old_must=MUST_OLD, new_must=MUST_OLD, old_may=MAY_OLD,
+           new_may=MAY_NEW)
 
-    trigger_schema_push(topology)
-    master_schema_csn = topology.master.schema.get_schema_csn()
-    consumer_schema_csn = topology.consumer.schema.get_schema_csn()
+    trigger_schema_push(topology_m1c1)
+    master_schema_csn = topology_m1c1.ms["master1"].schema.get_schema_csn()
+    consumer_schema_csn = topology_m1c1.cs["consumer1"].schema.get_schema_csn()
 
     # Check the schemaCSN was not updated on the consumer
     # with 47721, supplier learns the missing definition
     log.debug("test_ticket47490_eight master_schema_csn=%s", master_schema_csn)
     log.debug("ctest_ticket47490_eight onsumer_schema_csn=%s", consumer_schema_csn)
-    if support_schema_learning(topology):
+    if support_schema_learning(topology_m1c1):
         assert master_schema_csn == consumer_schema_csn
     else:
         assert master_schema_csn != consumer_schema_csn
@@ -607,10 +526,10 @@ def test_ticket47490_eight(topology):
     # Check the error log of the supplier does not contain an error
     # This message may happen during the learning phase
     regex = re.compile("must not be overwritten \(set replication log for additional info\)")
-    res = pattern_errorlog(topology.master.errorlog_file, regex)
+    res = pattern_errorlog(topology_m1c1.ms["master1"].errorlog_file, regex)
 
 
-def test_ticket47490_nine(topology):
+def test_ticket47490_nine(topology_m1c1):
     """
         Summary: Same OC - extra MAY: Schema is pushed - no error
 
@@ -633,13 +552,14 @@ def test_ticket47490_nine(topology):
                        +must=telexnumber                   +must=telexnumber
                        +may=postOfficeBox                  +may=postOfficeBox +may=postOfficeBox
     """
-    _header(topology, "Same OC - extra MAY: Schema is pushed - no error")
+    _header(topology_m1c1, "Same OC - extra MAY: Schema is pushed - no error")
 
-    mod_OC(topology.master, 1, 'consumerNewOCA', old_must=MUST_NEW, new_must=MUST_NEW, old_may=MAY_OLD, new_may=MAY_NEW)
+    mod_OC(topology_m1c1.ms["master1"], 1, 'consumerNewOCA', old_must=MUST_NEW, new_must=MUST_NEW, old_may=MAY_OLD,
+           new_may=MAY_NEW)
 
-    trigger_schema_push(topology)
-    master_schema_csn = topology.master.schema.get_schema_csn()
-    consumer_schema_csn = topology.consumer.schema.get_schema_csn()
+    trigger_schema_push(topology_m1c1)
+    master_schema_csn = topology_m1c1.ms["master1"].schema.get_schema_csn()
+    consumer_schema_csn = topology_m1c1.cs["consumer1"].schema.get_schema_csn()
 
     # Check the schemaCSN was updated on the consumer
     log.debug("test_ticket47490_nine master_schema_csn=%s", master_schema_csn)
@@ -648,7 +568,7 @@ def test_ticket47490_nine(topology):
 
     # Check the error log of the supplier does not contain an error
     regex = re.compile("must not be overwritten \(set replication log for additional info\)")
-    res = pattern_errorlog(topology.master.errorlog_file, regex)
+    res = pattern_errorlog(topology_m1c1.ms["master1"].errorlog_file, regex)
     if res is not None:
         assert False
 
@@ -660,4 +580,3 @@ if __name__ == '__main__':
     # -s for DEBUG mode
     CURRENT_FILE = os.path.realpath(__file__)
     pytest.main("-s %s" % CURRENT_FILE)
-
