@@ -1,76 +1,30 @@
 # --- BEGIN COPYRIGHT BLOCK ---
-# Copyright (C) 2015 Red Hat, Inc.
+# Copyright (C) 2016 Red Hat, Inc.
 # All rights reserved.
 #
 # License: GPL (version 3 or any later version).
 # See LICENSE for details.
 # --- END COPYRIGHT BLOCK ---
 #
-import os
-import sys
-import time
-import ldap
 import logging
+
 import pytest
-from lib389 import DirSrv, Entry, tools, tasks
-from lib389.tools import DirSrvTools
-from lib389._constants import *
-from lib389.properties import *
 from lib389.tasks import *
+from lib389.topologies import topology_st
+
+from lib389._constants import (defaultProperties, DEFAULT_SUFFIX, ReplicaRole,
+                               REPLICAID_MASTER_1, REPLICA_PRECISE_PURGING, REPLICA_PURGE_DELAY,
+                               REPLICA_PURGE_INTERVAL)
 
 log = logging.getLogger(__name__)
 
-installation_prefix = None
 
-
-class TopologyStandalone(object):
-    def __init__(self, standalone):
-        standalone.open()
-        self.standalone = standalone
-
-
-@pytest.fixture(scope="module")
-def topology(request):
-    '''
-        This fixture is used to standalone topology for the 'module'.
-    '''
-    global installation_prefix
-
-    if installation_prefix:
-        args_instance[SER_DEPLOYED_DIR] = installation_prefix
-
-    standalone = DirSrv(verbose=False)
-
-    # Args for the standalone instance
-    args_instance[SER_HOST] = HOST_STANDALONE
-    args_instance[SER_PORT] = PORT_STANDALONE
-    args_instance[SER_SERVERID_PROP] = SERVERID_STANDALONE
-    args_standalone = args_instance.copy()
-    standalone.allocate(args_standalone)
-
-    # Get the status of the instance and restart it if it exists
-    instance_standalone = standalone.exists()
-
-    # Remove the instance
-    if instance_standalone:
-        standalone.delete()
-
-    # Create the instance
-    standalone.create()
-
-    # Used to retrieve configuration information (dbdir, confdir...)
-    standalone.open()
-
-    def fin():
-        standalone.delete()
-    request.addfinalizer(fin)
-
-    # Here we have standalone instance up and running
-    return TopologyStandalone(standalone)
-
-
-def test_ticket47819(topology):
+def test_ticket47819(topology_st):
     """
+from lib389.utils import *
+
+# Skip on older versions
+pytestmark = pytest.mark.skipif(ds_is_older('1.3.4'), reason="Not implemented")
         Testing precise tombstone purging:
             [1]  Make sure "nsTombstoneCSN" is added to new tombstones
             [2]  Make sure an import of a replication ldif adds "nsTombstoneCSN"
@@ -85,8 +39,8 @@ def test_ticket47819(topology):
     # Setup Replication
     #
     log.info('Setting up replication...')
-    topology.standalone.replica.enableReplication(suffix=DEFAULT_SUFFIX, role=REPLICAROLE_MASTER,
-                                                  replicaId=REPLICAID_MASTER_1)
+    topology_st.standalone.replica.enableReplication(suffix=DEFAULT_SUFFIX, role=ReplicaRole.MASTER,
+                                                     replicaId=REPLICAID_MASTER_1)
 
     #
     # Part 1 create a tombstone entry and make sure nsTombstoneCSN is added
@@ -94,24 +48,24 @@ def test_ticket47819(topology):
     log.info('Part 1:  Add and then delete an entry to create a tombstone...')
 
     try:
-        topology.standalone.add_s(Entry(('cn=entry1,dc=example,dc=com', {
-                                  'objectclass': 'top person'.split(),
-                                  'sn': 'user',
-                                  'cn': 'entry1'})))
+        topology_st.standalone.add_s(Entry(('cn=entry1,dc=example,dc=com', {
+            'objectclass': 'top person'.split(),
+            'sn': 'user',
+            'cn': 'entry1'})))
     except ldap.LDAPError as e:
         log.error('Failed to add entry: ' + e.message['desc'])
         assert False
 
     try:
-        topology.standalone.delete_s('cn=entry1,dc=example,dc=com')
+        topology_st.standalone.delete_s('cn=entry1,dc=example,dc=com')
     except ldap.LDAPError as e:
         log.error('Failed to delete entry: ' + e.message['desc'])
         assert False
 
     log.info('Search for tombstone entries...')
     try:
-        entries = topology.standalone.search_s(DEFAULT_SUFFIX, ldap.SCOPE_SUBTREE,
-                                               '(&(nsTombstoneCSN=*)(objectclass=nsTombstone))')
+        entries = topology_st.standalone.search_s(DEFAULT_SUFFIX, ldap.SCOPE_SUBTREE,
+                                                  '(&(nsTombstoneCSN=*)(objectclass=nsTombstone))')
         if not entries:
             log.fatal('Search failed to the new tombstone(nsTombstoneCSN is probably missing).')
             assert False
@@ -134,7 +88,7 @@ def test_ticket47819(topology):
 
     args = {EXPORT_REPL_INFO: True,
             TASK_WAIT: True}
-    exportTask = Tasks(topology.standalone)
+    exportTask = Tasks(topology_st.standalone)
     try:
         exportTask.exportLDIF(DEFAULT_SUFFIX, None, ldif_file, args)
     except ValueError:
@@ -156,7 +110,7 @@ def test_ticket47819(topology):
 
     # import the new ldif file
     log.info('Import replication LDIF file...')
-    importTask = Tasks(topology.standalone)
+    importTask = Tasks(topology_st.standalone)
     args = {TASK_WAIT: True}
     try:
         importTask.importLDIF(DEFAULT_SUFFIX, None, ldif_file, args)
@@ -169,8 +123,8 @@ def test_ticket47819(topology):
     # Search for the tombstone again
     log.info('Search for tombstone entries...')
     try:
-        entries = topology.standalone.search_s(DEFAULT_SUFFIX, ldap.SCOPE_SUBTREE,
-                                               '(&(nsTombstoneCSN=*)(objectclass=nsTombstone))')
+        entries = topology_st.standalone.search_s(DEFAULT_SUFFIX, ldap.SCOPE_SUBTREE,
+                                                  '(&(nsTombstoneCSN=*)(objectclass=nsTombstone))')
         if not entries:
             log.fatal('Search failed to fine the new tombstone(nsTombstoneCSN is probably missing).')
             assert False
@@ -189,7 +143,7 @@ def test_ticket47819(topology):
     # so we can test if the fixup task works.
     args = {TASK_WAIT: True,
             TASK_TOMB_STRIP: True}
-    fixupTombTask = Tasks(topology.standalone)
+    fixupTombTask = Tasks(topology_st.standalone)
     try:
         fixupTombTask.fixupTombstones(DEFAULT_BENAME, args)
     except:
@@ -199,8 +153,8 @@ def test_ticket47819(topology):
     # Search for tombstones with nsTombstoneCSN - better not find any
     log.info('Search for tombstone entries...')
     try:
-        entries = topology.standalone.search_s(DEFAULT_SUFFIX, ldap.SCOPE_SUBTREE,
-                                               '(&(nsTombstoneCSN=*)(objectclass=nsTombstone))')
+        entries = topology_st.standalone.search_s(DEFAULT_SUFFIX, ldap.SCOPE_SUBTREE,
+                                                  '(&(nsTombstoneCSN=*)(objectclass=nsTombstone))')
         if entries:
             log.fatal('Search found tombstones with nsTombstoneCSN')
             assert False
@@ -208,10 +162,9 @@ def test_ticket47819(topology):
         log.fatal('Search failed: ' + e.message['desc'])
         assert False
 
-
     # Now run the fixup task
     args = {TASK_WAIT: True}
-    fixupTombTask = Tasks(topology.standalone)
+    fixupTombTask = Tasks(topology_st.standalone)
     try:
         fixupTombTask.fixupTombstones(DEFAULT_BENAME, args)
     except:
@@ -221,8 +174,8 @@ def test_ticket47819(topology):
     # Search for tombstones with nsTombstoneCSN - better find some
     log.info('Search for tombstone entries...')
     try:
-        entries = topology.standalone.search_s(DEFAULT_SUFFIX, ldap.SCOPE_SUBTREE,
-                                               '(&(nsTombstoneCSN=*)(objectclass=nsTombstone))')
+        entries = topology_st.standalone.search_s(DEFAULT_SUFFIX, ldap.SCOPE_SUBTREE,
+                                                  '(&(nsTombstoneCSN=*)(objectclass=nsTombstone))')
         if not entries:
             log.fatal('Search did not find any fixed-up tombstones')
             assert False
@@ -241,7 +194,7 @@ def test_ticket47819(topology):
             REPLICA_PURGE_DELAY: '5',
             REPLICA_PURGE_INTERVAL: '5'}
     try:
-        topology.standalone.replica.setProperties(DEFAULT_SUFFIX, None, None, args)
+        topology_st.standalone.replica.setProperties(DEFAULT_SUFFIX, None, None, args)
     except:
         log.fatal('Failed to configure replica')
         assert False
@@ -253,10 +206,10 @@ def test_ticket47819(topology):
     # Add an entry to trigger replication
     log.info('Perform an update to help trigger tombstone purging...')
     try:
-        topology.standalone.add_s(Entry(('cn=test_entry,dc=example,dc=com', {
-                                  'objectclass': 'top person'.split(),
-                                  'sn': 'user',
-                                  'cn': 'entry1'})))
+        topology_st.standalone.add_s(Entry(('cn=test_entry,dc=example,dc=com', {
+            'objectclass': 'top person'.split(),
+            'sn': 'user',
+            'cn': 'entry1'})))
     except ldap.LDAPError as e:
         log.error('Failed to add entry: ' + e.message['desc'])
         assert False
@@ -268,8 +221,8 @@ def test_ticket47819(topology):
     # search for tombstones, there should be none
     log.info('Search for tombstone entries...')
     try:
-        entries = topology.standalone.search_s(DEFAULT_SUFFIX, ldap.SCOPE_SUBTREE,
-                                               '(&(nsTombstoneCSN=*)(objectclass=nsTombstone))')
+        entries = topology_st.standalone.search_s(DEFAULT_SUFFIX, ldap.SCOPE_SUBTREE,
+                                                  '(&(nsTombstoneCSN=*)(objectclass=nsTombstone))')
         if entries:
             log.fatal('Search unexpectedly found tombstones')
             assert False
