@@ -1,79 +1,25 @@
 # --- BEGIN COPYRIGHT BLOCK ---
-# Copyright (C) 2015 Red Hat, Inc.
+# Copyright (C) 2016 Red Hat, Inc.
 # All rights reserved.
 #
 # License: GPL (version 3 or any later version).
 # See LICENSE for details.
 # --- END COPYRIGHT BLOCK ---
 #
-import os
-import sys
-import time
-import ldap
-import ldap.sasl
 import logging
+
+import ldap.sasl
 import pytest
-from lib389 import DirSrv, Entry, tools, tasks
-from lib389.tools import DirSrvTools
-from lib389._constants import *
-from lib389.properties import *
 from lib389.tasks import *
+from lib389.topologies import topology_st
 
 log = logging.getLogger(__name__)
 
-installation_prefix = None
-
 USER1_DN = "uid=user1,%s" % DEFAULT_SUFFIX
 USER2_DN = "uid=user2,%s" % DEFAULT_SUFFIX
 
 
-class TopologyStandalone(object):
-    def __init__(self, standalone):
-        standalone.open()
-        self.standalone = standalone
-
-
-@pytest.fixture(scope="module")
-def topology(request):
-    '''
-        This fixture is used to standalone topology for the 'module'.
-    '''
-    global installation_prefix
-
-    if installation_prefix:
-        args_instance[SER_DEPLOYED_DIR] = installation_prefix
-
-    standalone = DirSrv(verbose=False)
-
-    # Args for the standalone instance
-    args_instance[SER_HOST] = HOST_STANDALONE
-    args_instance[SER_PORT] = PORT_STANDALONE
-    args_instance[SER_SERVERID_PROP] = SERVERID_STANDALONE
-    args_standalone = args_instance.copy()
-    standalone.allocate(args_standalone)
-
-    # Get the status of the instance and restart it if it exists
-    instance_standalone = standalone.exists()
-
-    # Remove the instance
-    if instance_standalone:
-        standalone.delete()
-
-    # Create the instance
-    standalone.create()
-
-    # Used to retrieve configuration information (dbdir, confdir...)
-    standalone.open()
-
-    def fin():
-        standalone.delete()
-    request.addfinalizer(fin)
-
-    # Here we have standalone instance up and running
-    return TopologyStandalone(standalone)
-
-
-def test_ticket47970(topology):
+def test_ticket47970(topology_st):
     """
         Testing that a failed SASL bind does not trigger account lockout -
         which would attempt to update the passwordRetryCount on the root dse entry
@@ -85,14 +31,14 @@ def test_ticket47970(topology):
     # Enable account lockout
     #
     try:
-        topology.standalone.modify_s("cn=config", [(ldap.MOD_REPLACE, 'passwordLockout', 'on')])
+        topology_st.standalone.modify_s("cn=config", [(ldap.MOD_REPLACE, 'passwordLockout', 'on')])
         log.info('account lockout enabled.')
     except ldap.LDAPError as e:
         log.error('Failed to enable account lockout: ' + e.message['desc'])
         assert False
 
     try:
-        topology.standalone.modify_s("cn=config", [(ldap.MOD_REPLACE, 'passwordMaxFailure', '5')])
+        topology_st.standalone.modify_s("cn=config", [(ldap.MOD_REPLACE, 'passwordMaxFailure', '5')])
         log.info('passwordMaxFailure set.')
     except ldap.LDAPError as e:
         log.error('Failed to to set passwordMaxFailure: ' + e.message['desc'])
@@ -106,7 +52,7 @@ def test_ticket47970(topology):
         user_name = "mark"
         pw = "secret"
         auth_tokens = ldap.sasl.digest_md5(user_name, pw)
-        topology.standalone.sasl_interactive_bind_s("", auth_tokens)
+        topology_st.standalone.sasl_interactive_bind_s("", auth_tokens)
     except ldap.INVALID_CREDENTIALS as e:
         log.info("SASL Bind failed as expected")
         failed_as_expected = True
@@ -119,9 +65,9 @@ def test_ticket47970(topology):
     # Check that passwordRetryCount was not set on the root dse entry
     #
     try:
-        entry = topology.standalone.search_s("", ldap.SCOPE_BASE,
-                                             "passwordRetryCount=*",
-                                             ['passwordRetryCount'])
+        entry = topology_st.standalone.search_s("", ldap.SCOPE_BASE,
+                                                "passwordRetryCount=*",
+                                                ['passwordRetryCount'])
     except ldap.LDAPError as e:
         log.error('Failed to search Root DSE entry: ' + e.message['desc'])
         assert False
