@@ -19,6 +19,7 @@ Hewlett-Packard Development Company, L.P.
 ******************************************************************************/
 
 #include <limits.h> /* ULONG_MAX */
+#include "slapi-private.h"
 #include "nspr.h"
 
 #define CFG_LASTLOGIN_STATE_ATTR "stateAttrName"
@@ -49,50 +50,49 @@ Hewlett-Packard Development Company, L.P.
 #define CALLBACK_ERR -1
 #define CALLBACK_HANDLED 1
 
-typedef struct acct_plugin_cfg {
-	char* state_attr_name;
-	char* alt_state_attr_name;
-	char* spec_attr_name;
-	char* limit_attr_name;
-	int always_record_login;
-	char* always_record_login_attr;
-	unsigned long inactivitylimit;
+typedef struct acct_plugin_cfg
+{
+    char *state_attr_name;
+    char *alt_state_attr_name;
+    char *spec_attr_name;
+    char *limit_attr_name;
+    int always_record_login;
+    char *always_record_login_attr;
+    unsigned long inactivitylimit;
 } acctPluginCfg;
 
-typedef struct accountpolicy {
-	unsigned long inactivitylimit;
+typedef struct accountpolicy
+{
+    unsigned long inactivitylimit;
 } acctPolicy;
 
 /* acct_util.c */
-int get_acctpolicy( Slapi_PBlock *pb, Slapi_Entry *target_entry,
-	void *plugin_id, acctPolicy **policy );
-void free_acctpolicy( acctPolicy **policy );
-int has_attr( Slapi_Entry* target_entry, char* attr_name, char** val );
-char* get_attr_string_val( Slapi_Entry* e, char* attr_name );
-void* get_identity(void);
-void set_identity(void*);
-time_t gentimeToEpochtime( char *gentimestr );
-char* epochtimeToGentime( time_t epochtime ); 
-int update_is_allowed_attr (const char *attr);
+int get_acctpolicy(Slapi_PBlock *pb, Slapi_Entry *target_entry, void *plugin_id, acctPolicy **policy);
+void free_acctpolicy(acctPolicy **policy);
+int has_attr(Slapi_Entry *target_entry, char *attr_name, char **val);
+char *get_attr_string_val(Slapi_Entry *e, char *attr_name);
+void *get_identity(void);
+void set_identity(void *);
+time_t gentimeToEpochtime(char *gentimestr);
+char *epochtimeToGentime(time_t epochtime);
+int update_is_allowed_attr(const char *attr);
 
 /* acct_config.c */
-int acct_policy_load_config_startup( Slapi_PBlock* pb, void* plugin_id );
-acctPluginCfg* get_config(void);
+int acct_policy_load_config_startup(Slapi_PBlock *pb, void *plugin_id);
+acctPluginCfg *get_config(void);
 void free_config(void);
 
 /* acct_init.c */
 void acct_policy_set_plugin_sdn(Slapi_DN *pluginDN);
-Slapi_DN * acct_policy_get_plugin_sdn(void);
+Slapi_DN *acct_policy_get_plugin_sdn(void);
 void acct_policy_set_config_area(Slapi_DN *sdn);
-Slapi_DN * acct_policy_get_config_area(void);
+Slapi_DN *acct_policy_get_config_area(void);
 void config_rd_lock(void);
 void config_wr_lock(void);
 void config_unlock(void);
 
 /* acc_plugins.c */
-int acct_add_pre_op( Slapi_PBlock *pb );
-int acct_mod_pre_op( Slapi_PBlock *pb );
-int acct_del_pre_op( Slapi_PBlock *pb );
-int acct_post_op( Slapi_PBlock *pb );
-
-
+int acct_add_pre_op(Slapi_PBlock *pb);
+int acct_mod_pre_op(Slapi_PBlock *pb);
+int acct_del_pre_op(Slapi_PBlock *pb);
+int acct_post_op(Slapi_PBlock *pb);
