@@ -4,11 +4,11 @@
  * All rights reserved.
  *
  * License: GPL (version 3 or any later version).
- * See LICENSE for details. 
+ * See LICENSE for details.
  * END COPYRIGHT BLOCK **/
 
 #ifdef HAVE_CONFIG_H
-#  include <config.h>
+#include <config.h>
 #endif
 
 /*
@@ -36,30 +36,30 @@
  *      numbers) to be used.  Each one is tried in order when opening an
  *      LDAP connection.
  *    suffixes is a semicolon separated list of DNs (if a DN contains a
- *	semicolon it must be represented \3B),
+ *    semicolon it must be represented \3B),
  *    maxconns is a limit on how many connections will be made,
- *    maxconcurrency is a limit on how many operations can share a connection, 
+ *    maxconcurrency is a limit on how many operations can share a connection,
  *    timeout is a time limit in seconds for bind operations to complete (use
- *	0 to specify an infinite limit).
+ *    0 to specify an infinite limit).
  *    ldver is the LDAP protocol version to use to talk to the server (2 or 3)
  *    connlifetime is a time limit time in seconds for a connection to be
  *      used before it is closed and reopened (use 0 to specify an infinite
  *      limit).  connlifetime can be omitted in which case a default value
- *	is used; this is for compatibility with DS 4.0 which did not support
+ *    is used; this is for compatibility with DS 4.0 which did not support
  *      connlifetime.
  */
 
 
 /*
  * function prototypes
- */ 
+ */
 
 /*
  * static variables
  */
 /* for now, there is only one configuration and it is global to the plugin  */
-static PassThruConfig	theConfig;
-static int		inited = 0;
+static PassThruConfig theConfig;
+static int inited = 0;
 
 
 /*
@@ -70,18 +70,18 @@ static int		inited = 0;
  * XXXmcs: this function leaks memory if any errors occur.
  */
 int
-passthru_config( int argc, char **argv )
+passthru_config(int argc, char **argv)
 {
-    int			i, j, rc, tosecs, using_def_connlifetime, starttls = 0;
-    char		**suffixarray;
-    PassThruServer	*prevsrvr, *srvr = NULL;
-    PassThruSuffix	*suffix, *prevsuffix;
-    LDAPURLDesc		*ludp;
-    int			ret = LDAP_SUCCESS;
+    int i, j, rc, tosecs, using_def_connlifetime, starttls = 0;
+    char **suffixarray;
+    PassThruServer *prevsrvr, *srvr = NULL;
+    PassThruSuffix *suffix, *prevsuffix;
+    LDAPURLDesc *ludp;
+    int ret = LDAP_SUCCESS;
 
-    if ( inited ) {
-        slapi_log_error( SLAPI_LOG_FATAL, PASSTHRU_PLUGIN_SUBSYSTEM,
-                "only one pass through plugin instance can be used\n" );
+    if (inited) {
+        slapi_log_err(SLAPI_LOG_ERR, PASSTHRU_PLUGIN_SUBSYSTEM,
+                      "passthru_config - Only one pass through plugin instance can be used\n");
         ret = LDAP_PARAM_ERROR;
         goto error;
     }
@@ -92,10 +92,10 @@ passthru_config( int argc, char **argv )
      * It doesn't make sense to configure a pass through plugin without
      * providing at least one remote server.  Return an error if attempted.
      */
-    if ( argc < 1 ) {
-        slapi_log_error( SLAPI_LOG_FATAL, PASSTHRU_PLUGIN_SUBSYSTEM,
-                "no pass through servers found in configuration "
-                "(at least one must be listed)\n" );
+    if (argc < 1) {
+        slapi_log_err(SLAPI_LOG_ERR, PASSTHRU_PLUGIN_SUBSYSTEM,
+                      "passthru_config - No pass through servers found in configuration "
+                      "(at least one must be listed)\n");
         ret = LDAP_PARAM_ERROR;
         goto error;
     }
@@ -104,12 +104,12 @@ passthru_config( int argc, char **argv )
      * Parse argv[] values.
      */
     prevsrvr = NULL;
-    for ( i = 0; i < argc; ++i ) {
+    for (i = 0; i < argc; ++i) {
         int secure = 0;
         char *p = NULL;
 
-        srvr = (PassThruServer *)slapi_ch_calloc( 1, sizeof( PassThruServer ));
-        srvr->ptsrvr_url = slapi_ch_strdup( argv[i] );
+        srvr = (PassThruServer *)slapi_ch_calloc(1, sizeof(PassThruServer));
+        srvr->ptsrvr_url = slapi_ch_strdup(argv[i]);
 
         /*
          * since the ldap url may contain both spaces (to delimit multiple hosts)
@@ -122,10 +122,10 @@ passthru_config( int argc, char **argv )
          * also assumes suffixes do not have any / in them
          */
         if ((p = strrchr(srvr->ptsrvr_url, '/'))) { /* look for last / */
-            p = strchr(p, ' '); /* look for first space after last / */
+            p = strchr(p, ' ');                     /* look for first space after last / */
             if (p) {
                 if (!strchr(p, ',')) { /* no comma */
-                    p = NULL; /* just use defaults */
+                    p = NULL;          /* just use defaults */
                 }
             }
         }
@@ -137,7 +137,7 @@ passthru_config( int argc, char **argv )
              */
             srvr->ptsrvr_maxconnections = PASSTHRU_DEF_SRVR_MAXCONNECTIONS;
             srvr->ptsrvr_maxconcurrency = PASSTHRU_DEF_SRVR_MAXCONCURRENCY;
-            srvr->ptsrvr_timeout = (struct timeval *)slapi_ch_calloc( 1,sizeof( struct timeval ));
+            srvr->ptsrvr_timeout = (struct timeval *)slapi_ch_calloc(1, sizeof(struct timeval));
             srvr->ptsrvr_timeout->tv_sec = PASSTHRU_DEF_SRVR_TIMEOUT;
             srvr->ptsrvr_ldapversion = PASSTHRU_DEF_SRVR_PROTOCOL_VERSION;
             using_def_connlifetime = 1;
@@ -149,56 +149,59 @@ passthru_config( int argc, char **argv )
              * OR  maxconnections,maxconcurrency,timeout,ldapversion,lifetime,starttls
              */
             *p++ = '\0'; /* p points at space preceding optional arguments */
-            rc = sscanf( p, "%d,%d,%d,%d,%d,%d", &srvr->ptsrvr_maxconnections,
-                         &srvr->ptsrvr_maxconcurrency, &tosecs, &srvr->ptsrvr_ldapversion,
-                         &srvr->ptsrvr_connlifetime, &starttls);
-            if ( rc < 4 ) {
-                slapi_log_error( SLAPI_LOG_FATAL, PASSTHRU_PLUGIN_SUBSYSTEM,
-                        "server parameters should be in the form "
-                        "\"maxconnections,maxconcurrency,timeout,ldapversion,"
-                        "connlifetime\" (got \"%s\")\n", p );
+            rc = sscanf(p, "%d,%d,%d,%d,%d,%d", &srvr->ptsrvr_maxconnections,
+                        &srvr->ptsrvr_maxconcurrency, &tosecs, &srvr->ptsrvr_ldapversion,
+                        &srvr->ptsrvr_connlifetime, &starttls);
+            if (rc < 4) {
+                slapi_log_err(SLAPI_LOG_ERR, PASSTHRU_PLUGIN_SUBSYSTEM,
+                              "passthru_config - Server parameters should be in the form "
+                              "\"maxconnections,maxconcurrency,timeout,ldapversion,"
+                              "connlifetime\" (got \"%s\")\n",
+                              p);
                 ret = LDAP_PARAM_ERROR;
                 goto error;
-            } else if ( rc < 5 ) {
+            } else if (rc < 5) {
                 using_def_connlifetime = 1;
                 srvr->ptsrvr_connlifetime = PASSTHRU_DEF_SRVR_CONNLIFETIME;
                 starttls = 0;
-            } else if ( rc < 6 ) {
+            } else if (rc < 6) {
                 using_def_connlifetime = 0; /* lifetime specified */
-                starttls = 0; /* but not starttls */
-            } else { /* all 6 args supplied */
+                starttls = 0;               /* but not starttls */
+            } else {                        /* all 6 args supplied */
                 using_def_connlifetime = 0; /* lifetime specified */
                 /* and starttls */
             }
 
-            if ( srvr->ptsrvr_ldapversion != LDAP_VERSION2 && srvr->ptsrvr_ldapversion != LDAP_VERSION3 ) {
-                slapi_log_error( SLAPI_LOG_FATAL, PASSTHRU_PLUGIN_SUBSYSTEM,
-                        "LDAP protocol version should be %d or %d (got %d)\n",
-                        LDAP_VERSION2, LDAP_VERSION3, srvr->ptsrvr_ldapversion );
+            if (srvr->ptsrvr_ldapversion != LDAP_VERSION2 && srvr->ptsrvr_ldapversion != LDAP_VERSION3) {
+                slapi_log_err(SLAPI_LOG_ERR, PASSTHRU_PLUGIN_SUBSYSTEM,
+                              "passthru_config - LDAP protocol version should be %d or %d (got %d)\n",
+                              LDAP_VERSION2, LDAP_VERSION3, srvr->ptsrvr_ldapversion);
                 ret = LDAP_PARAM_ERROR;
                 goto error;
             }
 
-            if ( srvr->ptsrvr_maxconnections <= 0 ) {
-                slapi_log_error( SLAPI_LOG_FATAL, PASSTHRU_PLUGIN_SUBSYSTEM,
-                        "maximum connections must be greater than "
-                        "zero (got %d)\n", srvr->ptsrvr_maxconnections );
+            if (srvr->ptsrvr_maxconnections <= 0) {
+                slapi_log_err(SLAPI_LOG_ERR, PASSTHRU_PLUGIN_SUBSYSTEM,
+                              "passthru_config - Maximum connections must be greater than "
+                              "zero (got %d)\n",
+                              srvr->ptsrvr_maxconnections);
                 ret = LDAP_PARAM_ERROR;
                 goto error;
             }
 
-            if ( srvr->ptsrvr_maxconcurrency <= 0 ) {
-                slapi_log_error( SLAPI_LOG_FATAL, PASSTHRU_PLUGIN_SUBSYSTEM,
-                        "maximum concurrency must be greater than "
-                        "zero (got %d)\n", srvr->ptsrvr_maxconcurrency );
+            if (srvr->ptsrvr_maxconcurrency <= 0) {
+                slapi_log_err(SLAPI_LOG_ERR, PASSTHRU_PLUGIN_SUBSYSTEM,
+                              "passthru_config - Maximum concurrency must be greater than "
+                              "zero (got %d)\n",
+                              srvr->ptsrvr_maxconcurrency);
                 ret = LDAP_PARAM_ERROR;
                 goto error;
             }
 
-            if ( tosecs <= 0 ) {
+            if (tosecs <= 0) {
                 srvr->ptsrvr_timeout = NULL;
             } else {
-                srvr->ptsrvr_timeout = (struct timeval *)slapi_ch_calloc( 1, sizeof( struct timeval ));
+                srvr->ptsrvr_timeout = (struct timeval *)slapi_ch_calloc(1, sizeof(struct timeval));
                 srvr->ptsrvr_timeout->tv_sec = tosecs;
             }
         }
@@ -206,22 +209,22 @@ passthru_config( int argc, char **argv )
         /*
          * parse the LDAP URL
          */
-        if (( rc = slapi_ldap_url_parse( srvr->ptsrvr_url, &ludp, 1, &secure )) != 0 ) {
-            slapi_log_error( SLAPI_LOG_FATAL, PASSTHRU_PLUGIN_SUBSYSTEM,
-                    "unable to parse LDAP URL \"%s\" (%s)\n",
-                    srvr->ptsrvr_url, slapi_urlparse_err2string( rc ));
+        if ((rc = slapi_ldap_url_parse(srvr->ptsrvr_url, &ludp, 1, &secure)) != 0) {
+            slapi_log_err(SLAPI_LOG_ERR, PASSTHRU_PLUGIN_SUBSYSTEM,
+                          "passthru_config - Unable to parse LDAP URL \"%s\" (%s)\n",
+                          srvr->ptsrvr_url, slapi_urlparse_err2string(rc));
             ret = LDAP_PARAM_ERROR;
             goto error;
         }
 
-        if ( ludp->lud_dn == NULL || *ludp->lud_dn == '\0' ) {
-            slapi_log_error( SLAPI_LOG_FATAL, PASSTHRU_PLUGIN_SUBSYSTEM,
-                    "missing suffix in LDAP URL \"%s\"\n", srvr->ptsrvr_url );
+        if (ludp->lud_dn == NULL || *ludp->lud_dn == '\0') {
+            slapi_log_err(SLAPI_LOG_ERR, PASSTHRU_PLUGIN_SUBSYSTEM,
+                          "passthru_config - Missing suffix in LDAP URL \"%s\"\n", srvr->ptsrvr_url);
             ret = LDAP_PARAM_ERROR;
             goto error;
         }
-	
-        srvr->ptsrvr_hostname = slapi_ch_strdup( ludp->lud_host );
+
+        srvr->ptsrvr_hostname = slapi_ch_strdup(ludp->lud_host);
         srvr->ptsrvr_port = ludp->lud_port;
         srvr->ptsrvr_secure = secure;
         if (starttls) {
@@ -232,18 +235,18 @@ passthru_config( int argc, char **argv )
          * If a space-separated list of hosts is configured for failover,
          * use a different (non infinite) default for connection lifetime.
          */
-        if ( using_def_connlifetime &&
-            strchr( srvr->ptsrvr_hostname, ' ' ) != NULL ) {
+        if (using_def_connlifetime &&
+            strchr(srvr->ptsrvr_hostname, ' ') != NULL) {
             srvr->ptsrvr_connlifetime = PASSTHRU_DEF_SRVR_FAILOVERCONNLIFETIME;
         }
 
         /*
          * split the DN into multiple suffixes (separated by ';')
          */
-        if (( suffixarray = slapi_str2charray( ludp->lud_dn, ";" )) == NULL ) {
-            slapi_log_error( SLAPI_LOG_FATAL, PASSTHRU_PLUGIN_SUBSYSTEM,
-                    "unable to parse suffix string \"%s\" within \"%s\"\n",
-                    ludp->lud_dn, srvr->ptsrvr_url );
+        if ((suffixarray = slapi_str2charray(ludp->lud_dn, ";")) == NULL) {
+            slapi_log_err(SLAPI_LOG_ERR, PASSTHRU_PLUGIN_SUBSYSTEM,
+                          "passthru_config - Unable to parse suffix string \"%s\" within \"%s\"\n",
+                          ludp->lud_dn, srvr->ptsrvr_url);
             ret = LDAP_PARAM_ERROR;
             goto error;
         }
@@ -251,41 +254,40 @@ passthru_config( int argc, char **argv )
         /*
          * free our LDAP URL descriptor
          */
-        ldap_free_urldesc( ludp );
+        ldap_free_urldesc(ludp);
         ludp = NULL;
 
         /*
          * reorganize the suffixes into a linked list and normalize them
          */
         prevsuffix = NULL;
-        for ( j = 0; suffixarray[ j ] != NULL; ++j ) {
+        for (j = 0; suffixarray[j] != NULL; ++j) {
             /*
              * allocate a new PassThruSuffix structure and fill it in.
              */
-            suffix = (PassThruSuffix *)slapi_ch_calloc(1, sizeof( PassThruSuffix ));
-            suffix->ptsuffix_normsuffix = slapi_dn_normalize( suffixarray[ j ] );
-            suffixarray[ j ] = NULL;
-            suffix->ptsuffix_len = strlen( suffix->ptsuffix_normsuffix );
+            suffix = (PassThruSuffix *)slapi_ch_calloc(1, sizeof(PassThruSuffix));
+            suffix->ptsuffix_normsuffix = slapi_dn_normalize(suffixarray[j]);
+            suffixarray[j] = NULL;
+            suffix->ptsuffix_len = strlen(suffix->ptsuffix_normsuffix);
             suffix->ptsuffix_next = NULL;
 
             /*
              * add to end of list
              */
-            if ( prevsuffix == NULL ) {
+            if (prevsuffix == NULL) {
                 srvr->ptsrvr_suffixes = suffix;
             } else {
                 prevsuffix->ptsuffix_next = suffix;
             }
             prevsuffix = suffix;
         }
-        ldap_memfree( suffixarray );
+        ldap_memfree(suffixarray);
 
         /*
          * create mutexes and condition variables for this server
          */
-        if (( srvr->ptsrvr_connlist_mutex = slapi_new_mutex()) == NULL ||
-            ( srvr->ptsrvr_connlist_cv = slapi_new_condvar(srvr->ptsrvr_connlist_mutex )) == NULL )
-        {
+        if ((srvr->ptsrvr_connlist_mutex = slapi_new_mutex()) == NULL ||
+            (srvr->ptsrvr_connlist_cv = slapi_new_condvar(srvr->ptsrvr_connlist_mutex)) == NULL) {
             ret = LDAP_LOCAL_ERROR;
             goto error;
         }
@@ -293,7 +295,7 @@ passthru_config( int argc, char **argv )
         /*
          * add this server to the end of our list
          */
-        if ( prevsrvr == NULL ) {
+        if (prevsrvr == NULL) {
             theConfig.ptconfig_serverlist = srvr;
         } else {
             prevsrvr->ptsrvr_next = srvr;
@@ -304,21 +306,20 @@ passthru_config( int argc, char **argv )
         /*
          * log configuration for debugging purposes
          */
-        slapi_log_error( SLAPI_LOG_PLUGIN, PASSTHRU_PLUGIN_SUBSYSTEM,
-                "PTA server host: \"%s\", port: %d, secure: %d, "
-                "maxconnections: %d, maxconcurrency: %d, timeout: %d, "
-                "ldversion: %d, connlifetime: %d\n",
-                srvr->ptsrvr_hostname, srvr->ptsrvr_port,
-                srvr->ptsrvr_secure, srvr->ptsrvr_maxconnections,
-                srvr->ptsrvr_maxconcurrency,
-                srvr->ptsrvr_timeout == NULL ? -1 : srvr->ptsrvr_timeout->tv_sec,
-                srvr->ptsrvr_ldapversion,
-                srvr->ptsrvr_connlifetime );
-        for ( prevsuffix = srvr->ptsrvr_suffixes; prevsuffix != NULL;
-              prevsuffix = prevsuffix->ptsuffix_next )
-        {
-            slapi_log_error( SLAPI_LOG_FATAL, PASSTHRU_PLUGIN_SUBSYSTEM,
-                    "   normalized suffix: \"%s\"\n", prevsuffix->ptsuffix_normsuffix );
+        slapi_log_err(SLAPI_LOG_PLUGIN, PASSTHRU_PLUGIN_SUBSYSTEM,
+                      "PTA server host: \"%s\", port: %d, secure: %d, "
+                      "maxconnections: %d, maxconcurrency: %d, timeout: %d, "
+                      "ldversion: %d, connlifetime: %d\n",
+                      srvr->ptsrvr_hostname, srvr->ptsrvr_port,
+                      srvr->ptsrvr_secure, srvr->ptsrvr_maxconnections,
+                      srvr->ptsrvr_maxconcurrency,
+                      srvr->ptsrvr_timeout == NULL ? -1 : srvr->ptsrvr_timeout->tv_sec,
+                      srvr->ptsrvr_ldapversion,
+                      srvr->ptsrvr_connlifetime);
+        for (prevsuffix = srvr->ptsrvr_suffixes; prevsuffix != NULL;
+             prevsuffix = prevsuffix->ptsuffix_next) {
+            slapi_log_err(SLAPI_LOG_DEBUG, PASSTHRU_PLUGIN_SUBSYSTEM,
+                          "   normalized suffix: \"%s\"\n", prevsuffix->ptsuffix_normsuffix);
         }
 #endif
 
@@ -327,7 +328,7 @@ passthru_config( int argc, char **argv )
     goto done;
 
 error:
-    slapi_ch_free((void**)&srvr);
+    slapi_ch_free((void **)&srvr);
 
 done:
     return ret;
@@ -339,25 +340,25 @@ done:
  * configuration and it is global to the plugin.
  */
 PassThruConfig *
-passthru_get_config( void )
+passthru_get_config(void)
 {
-    return( &theConfig );
+    return (&theConfig);
 }
 
 void
 passthru_free_config()
 {
-    PassThruServer	*server, *next_server;
-    PassThruSuffix	*suffix, *next_suffix;
+    PassThruServer *server, *next_server;
+    PassThruSuffix *suffix, *next_suffix;
 
     inited = 0;
     server = theConfig.ptconfig_serverlist;
-    while(server){
+    while (server) {
         next_server = server->ptsrvr_next;
         suffix = server->ptsrvr_suffixes;
 
         /* free the server's suffix list */
-        while(suffix){
+        while (suffix) {
             next_suffix = suffix->ptsuffix_next;
             slapi_ch_free_string(&suffix->ptsuffix_normsuffix);
             slapi_ch_free((void **)&suffix);
