@@ -3,16 +3,16 @@
  * All rights reserved.
  *
  * License: GPL (version 3 or any later version).
- * See LICENSE for details. 
+ * See LICENSE for details.
  * END COPYRIGHT BLOCK **/
 
 #ifdef HAVE_CONFIG_H
-#  include <config.h>
+#include <config.h>
 #endif
 
-/* 
+/*
  * Dynamic schema file reload plugin
- * 
+ *
  * plugin entry in dse.ldif
  * dn: cn=Schema Reload,cn=plugins,cn=config
  * objectClass: top
@@ -49,38 +49,36 @@
 
 static PRLock *schemareload_lock = NULL;
 
-static Slapi_PluginDesc pdesc = { "schemareload",
-    VENDOR, DS_PACKAGE_VERSION,
-    "task plugin to reload schema files" };
+static Slapi_PluginDesc pdesc = {"schemareload",
+                                 VENDOR, DS_PACKAGE_VERSION,
+                                 "task plugin to reload schema files"};
 
-static int schemareload_add(Slapi_PBlock *pb, Slapi_Entry *e,
-                    Slapi_Entry *eAfter, int *returncode, char *returntext,
-                    void *arg);
+static int schemareload_add(Slapi_PBlock *pb, Slapi_Entry *e, Slapi_Entry *eAfter, int *returncode, char *returntext, void *arg);
 static int schemareload_start(Slapi_PBlock *pb);
 static int schemareload_close(Slapi_PBlock *pb);
 static void schemareload_destructor(Slapi_Task *task);
 
-/* 
+/*
  * Init function
  * Specified in the plugin entry as "nsslapd-pluginInitfunc: schemareload_init"
  */
 int
-schemareload_init( Slapi_PBlock *pb )
+schemareload_init(Slapi_PBlock *pb)
 {
     int rc = 0;
 
-    rc = slapi_pblock_set( pb, SLAPI_PLUGIN_VERSION,
-                                    (void *) SLAPI_PLUGIN_VERSION_03 );
-    rc |= slapi_pblock_set( pb, SLAPI_PLUGIN_DESCRIPTION,
-        (void *)&pdesc );
-    rc |= slapi_pblock_set( pb, SLAPI_PLUGIN_START_FN,
-                                    (void *) schemareload_start );
-    rc |= slapi_pblock_set( pb, SLAPI_PLUGIN_CLOSE_FN, (void *) schemareload_close );
+    rc = slapi_pblock_set(pb, SLAPI_PLUGIN_VERSION,
+                          (void *)SLAPI_PLUGIN_VERSION_03);
+    rc |= slapi_pblock_set(pb, SLAPI_PLUGIN_DESCRIPTION,
+                           (void *)&pdesc);
+    rc |= slapi_pblock_set(pb, SLAPI_PLUGIN_START_FN,
+                           (void *)schemareload_start);
+    rc |= slapi_pblock_set(pb, SLAPI_PLUGIN_CLOSE_FN, (void *)schemareload_close);
 
     return rc;
 }
 
-/* 
+/*
  * Task start function
  * Register the function schemareload_add, which invokes the task on demand.
  */
@@ -90,11 +88,11 @@ schemareload_start(Slapi_PBlock *pb)
     int rc = 0;
 
     if ((schemareload_lock = PR_NewLock()) == NULL) {
-        slapi_log_error(SLAPI_LOG_FATAL, "schemareload", "Failed to create global schema reload lock.");
+        slapi_log_err(SLAPI_LOG_ERR, "schemareload", "schemareload_start - Failed to create global schema reload lock.");
         return -1;
     }
     rc = slapi_plugin_task_register_handler("schema reload task", schemareload_add, pb);
-    if(rc != LDAP_SUCCESS){
+    if (rc != LDAP_SUCCESS) {
         PR_DestroyLock(schemareload_lock);
     }
 
@@ -102,7 +100,7 @@ schemareload_start(Slapi_PBlock *pb)
 }
 
 static int
-schemareload_close(Slapi_PBlock *pb)
+schemareload_close(Slapi_PBlock *pb __attribute__((unused)))
 {
 
     slapi_plugin_task_unregister_handler("schema reload task", schemareload_add);
@@ -113,8 +111,8 @@ schemareload_close(Slapi_PBlock *pb)
 
 typedef struct _task_data
 {
-	char *schemadir;
-	char *bind_dn;
+    char *schemadir;
+    char *bind_dn;
 } task_data;
 
 /*
@@ -136,8 +134,8 @@ schemareload_thread(void *arg)
         return; /* no task */
     }
     slapi_task_inc_refcount(task);
-    slapi_log_error(SLAPI_LOG_PLUGIN, "schemareload",
-                    "schemareload_thread --> refcount incremented.\n" );
+    slapi_log_err(SLAPI_LOG_PLUGIN, "schemareload",
+                  "schemareload_thread --> refcount incremented.\n");
     /* Fetch our task data from the task */
     td = (task_data *)slapi_task_get_data(task);
 
@@ -146,9 +144,9 @@ schemareload_thread(void *arg)
 
     /* update task state to show it's running */
     slapi_task_begin(task, total_work);
-    PR_Lock(schemareload_lock);    /* make schema reload serialized */
-    slapi_task_log_notice(task, "Schema reload task starts (schema dir: %s) ...\n", td->schemadir?td->schemadir:"default");
-    slapi_log_error(SLAPI_LOG_FATAL, "schemareload", "Schema reload task starts (schema dir: %s) ...\n", td->schemadir?td->schemadir:"default");
+    PR_Lock(schemareload_lock); /* make schema reload serialized */
+    slapi_task_log_notice(task, "Schema reload task starts (schema dir: %s) ...\n", td->schemadir ? td->schemadir : "default");
+    slapi_log_err(SLAPI_LOG_INFO, "schemareload", "schemareload_thread - Schema reload task starts (schema dir: %s) ...\n", td->schemadir ? td->schemadir : "default");
 
     rv = slapi_validate_schema_files(td->schemadir);
     slapi_task_inc_progress(task);
@@ -156,11 +154,11 @@ schemareload_thread(void *arg)
     if (slapi_is_shutting_down()) {
         slapi_task_log_notice(task, "Server is shuttoing down; Schema validation aborted.");
         slapi_task_log_status(task, "Server is shuttoing down; Schema validation aborted.");
-        slapi_log_error(SLAPI_LOG_FATAL, "schemareload", "Server is shuttoing down; Schema validation aborted.");
+        slapi_log_err(SLAPI_LOG_ERR, "schemareload", "schemareload_thread - Server is shutting down; Schema validation aborted.");
     } else if (LDAP_SUCCESS == rv) {
         slapi_task_log_notice(task, "Schema validation passed.");
         slapi_task_log_status(task, "Schema validation passed.");
-        slapi_log_error(SLAPI_LOG_FATAL, "schemareload", "Schema validation passed.\n");
+        slapi_log_err(SLAPI_LOG_INFO, "schemareload", "schemareload_thread - Schema validation passed.\n");
 
         rv = slapi_reload_schema_files(td->schemadir);
         slapi_task_inc_progress(task);
@@ -169,32 +167,32 @@ schemareload_thread(void *arg)
         if (LDAP_SUCCESS == rv) {
             slapi_task_log_notice(task, "Schema reload task finished.");
             slapi_task_log_status(task, "Schema reload task finished.");
-            slapi_log_error(SLAPI_LOG_FATAL, "schemareload", "Schema reload task finished.\n");
+            slapi_log_err(SLAPI_LOG_INFO, "schemareload", "schemareload_thread - Schema reload task finished.\n");
         } else {
             slapi_task_log_notice(task, "Schema reload task failed.");
             slapi_task_log_status(task, "Schema reload task failed.");
-            slapi_log_error(SLAPI_LOG_FATAL, "schemareload", "Schema reload task failed.\n");
+            slapi_log_err(SLAPI_LOG_ERR, "schemareload", "schemareload_thread - Schema reload task failed.\n");
         }
     } else {
         slapi_task_log_notice(task, "Schema validation failed.");
         slapi_task_log_status(task, "Schema validation failed.");
-        slapi_log_error(SLAPI_LOG_FATAL, "schemareload", "Schema validation failed.\n");
+        slapi_log_err(SLAPI_LOG_ERR, "schemareload", "schemareload_thread - Schema validation failed.\n");
     }
     PR_Unlock(schemareload_lock);
 
     /* this will queue the destruction of the task */
     slapi_task_finish(task, rv);
     slapi_task_dec_refcount(task);
-    slapi_log_error(SLAPI_LOG_PLUGIN, "schemareload",
-                    "schemareload_thread <-- refcount decremented.\n");
+    slapi_log_err(SLAPI_LOG_PLUGIN, "schemareload",
+                  "schemareload_thread <-- refcount decremented.\n");
 }
 
 /* extract a single value from the entry (as a string) -- if it's not in the
  * entry, the default will be returned (which can be NULL).
  * you do not need to free anything returned by this.
  */
-static const char *fetch_attr(Slapi_Entry *e, const char *attrname,
-                                              const char *default_val)
+static const char *
+fetch_attr(Slapi_Entry *e, const char *attrname, const char *default_val)
 {
     Slapi_Attr *attr;
     Slapi_Value *val = NULL;
@@ -213,7 +211,7 @@ schemareload_destructor(Slapi_Task *task)
         task_data *mydata = (task_data *)slapi_task_get_data(task);
         while (slapi_task_get_refcount(task) > 0) {
             /* Yield to wait for the fixup task finishes. */
-            DS_Sleep (PR_MillisecondsToInterval(100));
+            DS_Sleep(PR_MillisecondsToInterval(100));
         }
         if (mydata) {
             slapi_ch_free_string(&mydata->schemadir);
@@ -230,9 +228,12 @@ schemareload_destructor(Slapi_Task *task)
  * the task.
  */
 static int
-schemareload_add(Slapi_PBlock *pb, Slapi_Entry *e,
-                    Slapi_Entry *eAfter, int *returncode, char *returntext,
-                    void *arg)
+schemareload_add(Slapi_PBlock *pb,
+                 Slapi_Entry *e,
+                 Slapi_Entry *eAfter __attribute__((unused)),
+                 int *returncode,
+                 char *returntext __attribute__((unused)),
+                 void *arg)
 {
     PRThread *thread = NULL;
     const char *schemadir = NULL;
@@ -257,15 +258,14 @@ schemareload_add(Slapi_PBlock *pb, Slapi_Entry *e,
     /* allocate new task now */
     task = slapi_plugin_new_task(slapi_entry_get_ndn(e), arg);
     if (task == NULL) {
-        slapi_log_error(SLAPI_LOG_FATAL, "schemareload", "unable to allocate new task!\n");
+        slapi_log_err(SLAPI_LOG_ERR, "schemareload", "schemareload_add - Unable to allocate new task!\n");
         *returncode = LDAP_OPERATIONS_ERROR;
         rv = SLAPI_DSE_CALLBACK_ERROR;
         goto out;
     }
 
-    mytaskdata = (task_data*)slapi_ch_malloc(sizeof(task_data));
-    if (mytaskdata == NULL)
-    {
+    mytaskdata = (task_data *)slapi_ch_malloc(sizeof(task_data));
+    if (mytaskdata == NULL) {
         *returncode = LDAP_OPERATIONS_ERROR;
         rv = SLAPI_DSE_CALLBACK_ERROR;
         goto out;
@@ -285,8 +285,8 @@ schemareload_add(Slapi_PBlock *pb, Slapi_Entry *e,
                              (void *)task, PR_PRIORITY_NORMAL, PR_GLOBAL_THREAD,
                              PR_UNJOINABLE_THREAD, SLAPD_DEFAULT_THREAD_STACKSIZE);
     if (thread == NULL) {
-        slapi_log_error(SLAPI_LOG_FATAL, "schemareload",
-                  "unable to create schema reload task thread!\n");
+        slapi_log_err(SLAPI_LOG_ERR, "schemareload",
+                      "schemareload_add - Unable to create schema reload task thread!\n");
         *returncode = LDAP_OPERATIONS_ERROR;
         rv = SLAPI_DSE_CALLBACK_ERROR;
     } else {
