@@ -217,6 +217,7 @@ connection_cleanup(Connection *conn)
     conn->c_connid = 0;
     conn->c_opsinitiated = 0;
     conn->c_opscompleted = 0;
+    conn->c_anonlimits_set = 0;
     conn->c_threadnumber = 0;
     conn->c_refcnt = 0;
     conn->c_idlesince = 0;
@@ -1498,8 +1499,6 @@ connection_threadmain()
     int maxthreads = 0;
     int enable_nunc_stans = 0;
     long bypasspollcnt = 0;
-    Connection *pb_conn = NULL;
-    Operation *pb_op = NULL;
 
     enable_nunc_stans = config_get_enable_nunc_stans();
 #if defined(hpux)
@@ -1520,18 +1519,14 @@ connection_threadmain()
         }
 
         if (!thread_turbo_flag && !more_data) {
+	        Connection *pb_conn = NULL;
+
             /* If more data is left from the previous connection_read_operation,
                we should finish the op now.  Client might be thinking it's
                done sending the request and wait for the response forever.
                [blackflag 624234] */
             ret = connection_wait_for_new_work(pb, interval);
 
-            /*
-             * Connection wait for new work provides the conn and op for us.
-             */
-            slapi_pblock_get(pb, SLAPI_CONNECTION, &pb_conn);
-            slapi_pblock_get(pb, SLAPI_OPERATION, &pb_op);
-
             switch (ret) {
             case CONN_NOWORK:
                 PR_ASSERT(interval != PR_INTERVAL_NO_TIMEOUT); /* this should never happen with PR_INTERVAL_NO_TIMEOUT */
@@ -1544,15 +1539,24 @@ connection_threadmain()
                 return;
             case CONN_FOUND_WORK_TO_DO:
                 /* note - don't need to lock here - connection should only
-                       be used by this thread - since c_gettingber is set to 1
-                       in connection_activity when the conn is added to the
-                       work queue, setup_pr_read_pds won't add the connection prfd
-                       to the poll list */
-                if (pb_conn->c_opscompleted == 0) {
+                   be used by this thread - since c_gettingber is set to 1
+                   in connection_activity when the conn is added to the
+                   work queue, setup_pr_read_pds won't add the connection prfd
+                   to the poll list */
+                slapi_pblock_get(pb, SLAPI_CONNECTION, &pb_conn);
+                if (pb_conn == NULL) {
+                    slapi_log_err(SLAPI_LOG_ERR, "connection_threadmain", "pb_conn is NULL\n");
+                    slapi_pblock_destroy(pb);
+                    g_decr_active_threadcnt();
+                    return;
+                }
+
+                PR_EnterMonitor(pb_conn->c_mutex);
+                if (pb_conn->c_anonlimits_set == 0) {
                     /*
-                         * We have a new connection, set the anonymous reslimit idletimeout
-                         * if applicable.
-                         */
+                     * We have a new connection, set the anonymous reslimit idletimeout
+                     * if applicable.
+                     */
                     char *anon_dn = config_get_anon_limits_dn();
                     int idletimeout;
                     /* If an anonymous limits dn is set, use it to set the limits. */
@@ -1567,11 +1571,19 @@ connection_threadmain()
                         }
                     }
                     slapi_ch_free_string(&anon_dn);
+                    /*
+                     * Set connection as initialized to avoid setting anonymous limits
+                     * multiple times on the same connection
+                     */
+                    pb_conn->c_anonlimits_set = 1;
                 }
+                PR_ExitMonitor(pb_conn->c_mutex);
+
                 if (connection_call_io_layer_callbacks(pb_conn)) {
                     slapi_log_err(SLAPI_LOG_ERR, "connection_threadmain",
                                   "Could not add/remove IO layers from connection\n");
                 }
+                break;
             default:
                 break;
             }
@@ -1598,6 +1610,12 @@ connection_threadmain()
         /* Once we're here we have a pb */
         slapi_pblock_get(pb, SLAPI_CONNECTION, &conn);
         slapi_pblock_get(pb, SLAPI_OPERATION, &op);
+        if (conn == NULL || op == NULL) {
+            slapi_log_err(SLAPI_LOG_ERR, "connection_threadmain", "NULL param: conn (0x%p) op (0x%p)\n", conn, op);
+            slapi_pblock_destroy(pb);
+            g_decr_active_threadcnt();
+            return;
+        }
         maxthreads = config_get_maxthreadsperconn();
         more_data = 0;
         ret = connection_read_operation(conn, op, &tag, &more_data);
@@ -1703,11 +1721,11 @@ connection_threadmain()
                  * so need locking from here on */
                 signal_listner();
                 /* with nunc-stans, I see an enormous amount of time spent in the poll() in
- * connection_read_operation() when the below code is enabled - not sure why
- * nunc-stans makes such a huge difference - for now, just disable this code
- * when using nunc-stans - it is supposed to be an optimization but turns out
- * to not be the opposite with nunc-stans
- */
+                 * connection_read_operation() when the below code is enabled - not sure why
+                 * nunc-stans makes such a huge difference - for now, just disable this code
+                 * when using nunc-stans - it is supposed to be an optimization but turns out
+                 * to not be the opposite with nunc-stans
+                 */
             } else if (!enable_nunc_stans) { /* more data in conn - just put back on work_q - bypass poll */
                 bypasspollcnt++;
                 PR_EnterMonitor(conn->c_mutex);
@@ -1786,7 +1804,7 @@ connection_threadmain()
         /* total number of ops for the server */
         slapi_counter_increment(ops_completed);
         /* If this op isn't a persistent search, remove it */
-        if (pb_op->o_flags & OP_FLAG_PS) {
+        if (op->o_flags & OP_FLAG_PS) {
             PR_EnterMonitor(conn->c_mutex);
             connection_release_nolock(conn); /* psearch acquires ref to conn - release this one now */
             PR_ExitMonitor(conn->c_mutex);
@@ -2177,6 +2195,13 @@ log_ber_too_big_error(const Connection *conn, ber_len_t ber_len, ber_len_t maxbe
                       " is %" BERLEN_T " bytes. Change the nsslapd-maxbersize attribute in"
                       " cn=config to increase.\n",
                       conn->c_connid, conn->c_sd, maxbersize);
+    } else if (ber_len < maxbersize) {
+        /* This means the request was misformed, not too large. */
+        slapi_log_err(SLAPI_LOG_ERR, "log_ber_too_big_error",
+                      "conn=%" PRIu64 " fd=%d Incoming BER Element may be misformed. "
+                      "This may indicate an attempt to use TLS on a plaintext port, "
+                      "IE ldaps://localhost:389. Check your client LDAP_URI settings.\n",
+                      conn->c_connid, conn->c_sd);
     } else {
         slapi_log_err(SLAPI_LOG_ERR, "log_ber_too_big_error",
                       "conn=%" PRIu64 " fd=%d Incoming BER Element was %" BERLEN_T " bytes, max allowable"
