@@ -292,7 +292,11 @@ get_filter_internal(Connection *conn, BerElement *ber, struct slapi_filter **fil
 
     case LDAP_FILTER_EXTENDED:
         slapi_log_err(SLAPI_LOG_FILTER, "get_filter_internal", "EXTENDED\n");
-        if (conn->c_ldapversion < 3) {
+        if (conn == NULL) {
+            slapi_log_err(SLAPI_LOG_ERR, "get_filter_internal",
+                          "NULL param: conn (0x%p)\n", conn);
+            err = LDAP_OPERATIONS_ERROR;
+        } else if (conn->c_ldapversion < 3) {
             slapi_log_err(SLAPI_LOG_ERR, "get_filter_internal",
                           "Extensible filter received from v2 client\n");
             err = LDAP_PROTOCOL_ERROR;
@@ -682,11 +686,13 @@ slapi_filter_dup(Slapi_Filter *f)
         outl = &out->f_list;
         for (fl = f->f_list; fl != NULL; fl = fl->f_next) {
             (*outl) = slapi_filter_dup(fl);
-            (*outl)->f_next = 0;
-            if (lastout)
-                lastout->f_next = *outl;
-            lastout = *outl;
-            outl = &((*outl)->f_next);
+            if (*outl){
+                (*outl)->f_next = 0;
+                if (lastout)
+                    lastout->f_next = *outl;
+                lastout = *outl;
+                outl = &((*outl)->f_next);
+            }
         }
         break;
 
