@@ -134,7 +134,7 @@ ps_stop_psearch_system()
     if (PS_IS_INITIALIZED()) {
         PSL_LOCK_WRITE();
         for (ps = psearch_list->pl_head; NULL != ps; ps = ps->ps_next) {
-            __atomic_add_fetch_8(&(ps->ps_complete), 1, __ATOMIC_RELEASE);
+            slapi_atomic_incr_64(&(ps->ps_complete), __ATOMIC_RELEASE);
         }
         PSL_UNLOCK_WRITE();
         ps_wakeup_all();
@@ -271,6 +271,11 @@ ps_send_results(void *arg)
     slapi_pblock_get(ps->ps_pblock, SLAPI_CONNECTION, &pb_conn);
     slapi_pblock_get(ps->ps_pblock, SLAPI_OPERATION, &pb_op);
 
+    if (pb_conn == NULL) {
+        slapi_log_err(SLAPI_LOG_ERR, "ps_send_results", "pb_conn is NULL\n");
+        return;
+    }
+
     /* need to acquire a reference to this connection so that it will not
        be released or cleaned up out from under us */
     PR_EnterMonitor(pb_conn->c_mutex);
@@ -280,17 +285,17 @@ ps_send_results(void *arg)
     if (conn_acq_flag) {
         slapi_log_err(SLAPI_LOG_CONNS, "ps_send_results",
                       "conn=%" PRIu64 " op=%d Could not acquire the connection - psearch aborted\n",
-                      pb_conn->c_connid, pb_op->o_opid);
+                      pb_conn->c_connid, pb_op ? pb_op->o_opid : -1);
     }
 
     PR_Lock(psearch_list->pl_cvarlock);
 
-    while ((conn_acq_flag == 0) && __atomic_load_8(&(ps->ps_complete), __ATOMIC_ACQUIRE) == 0) {
+    while ((conn_acq_flag == 0) && slapi_atomic_load_64(&(ps->ps_complete), __ATOMIC_ACQUIRE) == 0) {
         /* Check for an abandoned operation */
         if (pb_op == NULL || slapi_op_abandoned(ps->ps_pblock)) {
             slapi_log_err(SLAPI_LOG_CONNS, "ps_send_results",
                           "conn=%" PRIu64 " op=%d The operation has been abandoned\n",
-                          pb_conn->c_connid, pb_op->o_opid);
+                          pb_conn->c_connid, pb_op ? pb_op->o_opid : -1);
             break;
         }
         if (NULL == ps->ps_eq_head) {
@@ -348,8 +353,8 @@ ps_send_results(void *arg)
                 if (rc) {
                     slapi_log_err(SLAPI_LOG_CONNS, "ps_send_results",
                                   "conn=%" PRIu64 " op=%d Error %d sending entry %s with op status %d\n",
-                                  pb_conn->c_connid, pb_op->o_opid,
-                                  rc, slapi_entry_get_dn_const(ec), pb_op->o_status);
+                                  pb_conn->c_connid, pb_op ? pb_op->o_opid: -1,
+                                  rc, slapi_entry_get_dn_const(ec), pb_op ? pb_op->o_status : -1);
                 }
             }
 
@@ -396,7 +401,7 @@ ps_send_results(void *arg)
 
     slapi_log_err(SLAPI_LOG_CONNS, "ps_send_results",
                   "conn=%" PRIu64 " op=%d Releasing the connection and operation\n",
-                  conn->c_connid, pb_op->o_opid);
+                  conn->c_connid, pb_op ? pb_op->o_opid : -1);
     /* Delete this op from the connection's list */
     connection_remove_operation_ext(ps->ps_pblock, conn, pb_op);
 
@@ -437,7 +442,7 @@ psearch_alloc(void)
         slapi_ch_free((void **)&ps);
         return (NULL);
     }
-    __atomic_store_8(&(ps->ps_complete), 0, __ATOMIC_RELEASE);
+    slapi_atomic_store_64(&(ps->ps_complete), 0, __ATOMIC_RELEASE);
     ps->ps_eq_head = ps->ps_eq_tail = (PSEQNode *)NULL;
     ps->ps_lasttime = (time_t)0L;
     ps->ps_next = NULL;
@@ -532,7 +537,7 @@ ps_service_persistent_searches(Slapi_Entry *e, Slapi_Entry *eprev, ber_int_t chg
         slapi_log_err(SLAPI_LOG_CONNS, "ps_service_persistent_searches",
                       "conn=%" PRIu64 " op=%d entry %s with chgtype %d "
                       "matches the ps changetype %d\n",
-                      pb_conn->c_connid,
+                      pb_conn ? pb_conn->c_connid : -1,
                       pb_op->o_opid,
                       edn, chgtype, ps->ps_changetypes);
 
@@ -609,7 +614,7 @@ ps_service_persistent_searches(Slapi_Entry *e, Slapi_Entry *eprev, ber_int_t chg
         /* Turn 'em loose */
         ps_wakeup_all();
         slapi_log_err(SLAPI_LOG_TRACE, "ps_service_persistent_searches", "Enqueued entry "
-                                                                         "\"%s\" on %d persistent search lists\n",
+                      "\"%s\" on %d persistent search lists\n",
                       slapi_entry_get_dn_const(e), matched);
     } else {
         slapi_log_err(SLAPI_LOG_TRACE, "ps_service_persistent_searches",
