@@ -3,11 +3,11 @@
  * All rights reserved.
  *
  * License: GPL (version 3 or any later version).
- * See LICENSE for details. 
+ * See LICENSE for details.
  * --- END COPYRIGHT BLOCK --- */
 
 #ifdef HAVE_CONFIG_H
-#  include <config.h>
+#include <config.h>
 #endif
 
 
@@ -24,17 +24,17 @@ static netsnmp_table_array_callbacks entity_cb;
 extern server_instance *server_head;
 
 /* Set table oids */
-oid    dsOpsTable_oid[] = { dsOpsTable_TABLE_OID };
+oid dsOpsTable_oid[] = {dsOpsTable_TABLE_OID};
 size_t dsOpsTable_oid_len = OID_LENGTH(dsOpsTable_oid);
-oid    dsEntriesTable_oid[] = { dsEntriesTable_TABLE_OID };
+oid dsEntriesTable_oid[] = {dsEntriesTable_TABLE_OID};
 size_t dsEntriesTable_oid_len = OID_LENGTH(dsEntriesTable_oid);
-oid    dsEntityTable_oid[] = {dsEntityTable_TABLE_OID };
+oid dsEntityTable_oid[] = {dsEntityTable_TABLE_OID};
 size_t dsEntityTable_oid_len = OID_LENGTH(dsEntityTable_oid);
 
 /* Set trap oids */
-oid    snmptrap_oid[] = { snmptrap_OID };
+oid snmptrap_oid[] = {snmptrap_OID};
 size_t snmptrap_oid_len = OID_LENGTH(snmptrap_oid);
-oid    enterprise_oid[] = { enterprise_OID };
+oid enterprise_oid[] = {enterprise_OID};
 size_t enterprise_oid_len = OID_LENGTH(enterprise_oid);
 
 /************************************************************
@@ -70,7 +70,7 @@ init_ldap_agent(void)
             } else {
                 /* error during malloc of row */
                 snmp_log(LOG_ERR, "Error creating row for server: %d\n",
-                                   serv_p->port);
+                         serv_p->port);
             }
         }
     }
@@ -91,7 +91,7 @@ initialize_stats_table(void)
     netsnmp_table_registration_info *ops_table_info = NULL;
     netsnmp_table_registration_info *entries_table_info = NULL;
     netsnmp_table_registration_info *entity_table_info = NULL;
-    /* This is a hacky way of figuring out if we are on Net-SNMP 5.2 or later */
+/* This is a hacky way of figuring out if we are on Net-SNMP 5.2 or later */
 #ifdef NETSNMP_CACHE_AUTO_RELOAD
     netsnmp_cache *stats_table_cache = NULL;
 #endif
@@ -112,20 +112,20 @@ initialize_stats_table(void)
 
     /* create handlers */
     ops_handler = netsnmp_create_handler_registration("dsOpsTable",
-                                                     netsnmp_table_array_helper_handler,
-                                                     dsOpsTable_oid,
-                                                     dsOpsTable_oid_len,
-                                                     HANDLER_CAN_RONLY);
+                                                      netsnmp_table_array_helper_handler,
+                                                      dsOpsTable_oid,
+                                                      dsOpsTable_oid_len,
+                                                      HANDLER_CAN_RONLY);
     entries_handler = netsnmp_create_handler_registration("dsEntriesTable",
-                                                     netsnmp_table_array_helper_handler,
-                                                     dsEntriesTable_oid,
-                                                     dsEntriesTable_oid_len,
-                                                     HANDLER_CAN_RONLY);
+                                                          netsnmp_table_array_helper_handler,
+                                                          dsEntriesTable_oid,
+                                                          dsEntriesTable_oid_len,
+                                                          HANDLER_CAN_RONLY);
     entity_handler = netsnmp_create_handler_registration("dsEntityTable",
-                                                     netsnmp_table_array_helper_handler,
-                                                     dsEntityTable_oid,
-                                                     dsEntityTable_oid_len,
-                                                     HANDLER_CAN_RONLY);
+                                                         netsnmp_table_array_helper_handler,
+                                                         dsEntityTable_oid,
+                                                         dsEntityTable_oid_len,
+                                                         HANDLER_CAN_RONLY);
 
     if (!ops_handler || !entries_handler || !entity_handler ||
         !ops_table_info || !entries_table_info || !entity_table_info) {
@@ -149,13 +149,14 @@ initialize_stats_table(void)
     entity_table_info->min_column = dsEntityTable_COL_MIN;
     entity_table_info->max_column = dsEntityTable_COL_MAX;
 
-    /* 
+    /*
      * Define callbacks and the container.  We only use one container that
      * all of the tables use.
      */
     ops_cb.get_value = dsOpsTable_get_value;
     ops_cb.container = netsnmp_container_find("dsOpsTable_primary:"
-                                          "dsOpsTable:" "table_container");
+                                              "dsOpsTable:"
+                                              "table_container");
     entries_cb.get_value = dsEntriesTable_get_value;
     entries_cb.container = ops_cb.container;
     entity_cb.get_value = dsEntityTable_get_value;
@@ -169,11 +170,11 @@ initialize_stats_table(void)
     netsnmp_table_container_register(entity_handler, entity_table_info, &entity_cb,
                                      entity_cb.container, 1);
 
-    /* Setup cache for auto reloading of stats */
+/* Setup cache for auto reloading of stats */
 #ifdef NETSNMP_CACHE_AUTO_RELOAD
     /* This is new api as of Net-SNMP 5.2 */
     stats_table_cache = netsnmp_cache_create(CACHE_REFRESH_INTERVAL, load_stats_table,
-                                            NULL, dsOpsTable_oid, dsOpsTable_oid_len);
+                                             NULL, dsOpsTable_oid, dsOpsTable_oid_len);
     stats_table_cache->flags |= NETSNMP_CACHE_DONT_FREE_EXPIRED;
     stats_table_cache->flags |= NETSNMP_CACHE_DONT_AUTO_RELEASE;
     stats_table_cache->flags |= NETSNMP_CACHE_AUTO_RELOAD;
@@ -181,7 +182,7 @@ initialize_stats_table(void)
 #else
     /* Do things the old way.  This is only needed for Net-SNMP 5.1 and earlier. */
     netsnmp_inject_handler(ops_handler, netsnmp_get_cache_handler(CACHE_REFRESH_INTERVAL, load_stats_table,
-                                            free_stats_table, dsOpsTable_oid, dsOpsTable_oid_len));
+                                                                  free_stats_table, dsOpsTable_oid, dsOpsTable_oid_len));
 #endif
 }
 
@@ -214,8 +215,10 @@ stats_table_create_row(unsigned long portnum)
     return ctx;
 
 error:
-    if (index_oid) free(index_oid);
-    if (ctx) SNMP_FREE(ctx);
+    if (index_oid)
+        free(index_oid);
+    if (ctx)
+        SNMP_FREE(ctx);
     return NULL;
 }
 
@@ -230,11 +233,11 @@ stats_table_find_row(unsigned long portnum)
 {
     netsnmp_index index;
     oid index_oid[MAX_OID_LEN];
-                                                                                                      
+
     index_oid[0] = portnum;
     index.oids = index_oid;
     index.len = 1;
-                                                                                                      
+
     return (stats_table_context *)
         CONTAINER_FIND(ops_cb.container, &index);
 }
@@ -249,7 +252,7 @@ stats_table_find_row(unsigned long portnum)
  * be sent here.
  */
 int
-load_stats_table(netsnmp_cache *cache, void *foo)
+load_stats_table(netsnmp_cache *cache __attribute__((unused)), void *foo __attribute__((unused)))
 {
     server_instance *serv_p = NULL;
     stats_table_context *ctx = NULL;
@@ -279,7 +282,7 @@ load_stats_table(netsnmp_cache *cache, void *foo)
                 int i = 0;
                 int got_sem = 0;
 
-                for (i=0; i < SNMP_NUM_SEM_WAITS; i++) {
+                for (i = 0; i < SNMP_NUM_SEM_WAITS; i++) {
                     if (sem_trywait(stats_sem) == 0) {
                         got_sem = 1;
                         break;
@@ -311,18 +314,18 @@ load_stats_table(netsnmp_cache *cache, void *foo)
                 memset(&ctx->entries_tbl, 0x00, sizeof(ctx->entries_tbl));
                 if (previous_state != SERVER_DOWN)
                     snmp_log(LOG_INFO, "Unable to open stats file (%s) for server: %d\n",
-                                       serv_p->stats_file, serv_p->port);
+                             serv_p->stats_file, serv_p->port);
             } else {
                 /* Initialize ops table */
-                if ( agt_mread_stats(stats_hdl, &ctx->hdr_tbl, &ctx->ops_tbl,
-                                           &ctx->entries_tbl) != 0 )
+                if (agt_mread_stats(stats_hdl, &ctx->hdr_tbl, &ctx->ops_tbl,
+                                    &ctx->entries_tbl) != 0)
                     snmp_log(LOG_ERR, "Unable to read stats file: %s\n",
-                                       serv_p->stats_file);
-                                                                                                                
+                             serv_p->stats_file);
+
                 /* Close stats file */
-                if ( agt_mclose_stats(stats_hdl) != 0 )
+                if (agt_mclose_stats(stats_hdl) != 0)
                     snmp_log(LOG_ERR, "Error closing stats file: %s\n",
-                                       serv_p->stats_file);
+                             serv_p->stats_file);
 
                 /* Release and close semaphore */
                 sem_post(stats_sem);
@@ -334,7 +337,8 @@ load_stats_table(netsnmp_cache *cache, void *foo)
                     serv_p->server_state = SERVER_DOWN;
                     if (previous_state != SERVER_DOWN)
                         snmp_log(LOG_INFO, "Stats file for server %d hasn't been updated"
-                                    " in %d seconds.\n", serv_p->port, UPDATE_THRESHOLD);
+                                           " in %d seconds.\n",
+                                 serv_p->port, UPDATE_THRESHOLD);
                 } else {
                     serv_p->server_state = SERVER_UP;
                 }
@@ -346,14 +350,14 @@ load_stats_table(netsnmp_cache *cache, void *foo)
                 if (serv_p->server_state != previous_state) {
                     if (serv_p->server_state == SERVER_UP) {
                         snmp_log(LOG_INFO, "Detected start of server: %d\n",
-                                            serv_p->port);
+                                 serv_p->port);
                         send_DirectoryServerStart_trap(serv_p);
                     } else {
                         send_DirectoryServerDown_trap(serv_p);
                         /* Zero out the ops and entries tables */
                         memset(&ctx->ops_tbl, 0x00, sizeof(ctx->ops_tbl));
                         memset(&ctx->entries_tbl, 0x00, sizeof(ctx->entries_tbl));
-                    } 
+                    }
                 } else if (ctx->hdr_tbl.startTime != previous_start) {
                     /* Send traps if the server has restarted since the last load */
                     snmp_log(LOG_INFO, "Detected restart of server: %d\n", serv_p->port);
@@ -364,7 +368,7 @@ load_stats_table(netsnmp_cache *cache, void *foo)
         } else {
             /* Can't find our row.  This shouldn't ever happen. */
             snmp_log(LOG_ERR, "Row not found for server: %d\n",
-                               serv_p->port);
+                     serv_p->port);
         }
     }
     return 0;
@@ -379,7 +383,7 @@ load_stats_table(netsnmp_cache *cache, void *foo)
  * function for freeing the cache, so here it is.
  */
 void
-free_stats_table(netsnmp_cache *cache, void *foo)
+free_stats_table(netsnmp_cache *cache __attribute__((unused)), void *foo __attribute__((unused)))
 {
     return;
 }
@@ -394,13 +398,13 @@ free_stats_table(netsnmp_cache *cache, void *foo)
  */
 int
 dsOpsTable_get_value(netsnmp_request_info *request,
-                     netsnmp_index * item,
+                     netsnmp_index *item,
                      netsnmp_table_request_info *table_info)
 {
     PRUint64 *the_stat = NULL;
     integer64 new_val;
     netsnmp_variable_list *var = request->requestvb;
-    stats_table_context *context = (stats_table_context *) item;
+    stats_table_context *context = (stats_table_context *)item;
 
     switch (table_info->colnum) {
 
@@ -496,7 +500,7 @@ dsOpsTable_get_value(netsnmp_request_info *request,
         the_stat = &context->ops_tbl.dsMaxThreadsHit;
         break;
 
-    default:/* We shouldn't get here */
+    default: /* We shouldn't get here */
         snmp_log(LOG_ERR, "Unknown column in dsOpsTable_get_value\n");
         return SNMP_ERR_GENERR;
     }
@@ -505,11 +509,11 @@ dsOpsTable_get_value(netsnmp_request_info *request,
      * a structure containing the high and low bits separately.  We need
      * to split our value appropriately. */
     new_val.low = *the_stat & 0x00000000ffffffff;
-    new_val.high =  (*the_stat >> 32) & 0x00000000ffffffff;
+    new_val.high = (*the_stat >> 32) & 0x00000000ffffffff;
 
     snmp_set_var_typed_value(var, ASN_COUNTER64,
-                                 (u_char *) &new_val,
-                                 sizeof(new_val));
+                             (u_char *)&new_val,
+                             sizeof(new_val));
 
     return SNMP_ERR_NOERROR;
 }
@@ -524,37 +528,37 @@ dsOpsTable_get_value(netsnmp_request_info *request,
  */
 int
 dsEntriesTable_get_value(netsnmp_request_info *request,
-                     netsnmp_index * item,
-                     netsnmp_table_request_info *table_info)
+                         netsnmp_index *item,
+                         netsnmp_table_request_info *table_info)
 {
     PRUint64 *the_stat = NULL;
     integer64 new_val;
     netsnmp_variable_list *var = request->requestvb;
-    stats_table_context *context = (stats_table_context *) item;
-                                                                                                                
+    stats_table_context *context = (stats_table_context *)item;
+
     switch (table_info->colnum) {
-                                                                                                                
+
     case COLUMN_DSMASTERENTRIES:
         the_stat = &context->entries_tbl.dsMasterEntries;
         break;
-                                                                                                                
+
     case COLUMN_DSCOPYENTRIES:
         the_stat = &context->entries_tbl.dsCopyEntries;
         break;
-                                                                                                                
+
     case COLUMN_DSCACHEENTRIES:
         the_stat = &context->entries_tbl.dsCacheEntries;
         break;
-                                                                                                                
+
     case COLUMN_DSCACHEHITS:
         the_stat = &context->entries_tbl.dsCacheHits;
         break;
-                                                                                                                
+
     case COLUMN_DSSLAVEHITS:
         the_stat = &context->entries_tbl.dsSlaveHits;
         break;
-                                                                                                                
-    default:/* We shouldn't get here */
+
+    default: /* We shouldn't get here */
         snmp_log(LOG_ERR, "Unknown column in dsEntriesTable_get_value\n");
         return SNMP_ERR_GENERR;
     }
@@ -563,11 +567,11 @@ dsEntriesTable_get_value(netsnmp_request_info *request,
      * a structure containing the high and low bits separately.  We need
      * to split our value appropriately. */
     new_val.low = *the_stat & 0x00000000ffffffff;
-    new_val.high =  (*the_stat >> 32) & 0x00000000ffffffff;
+    new_val.high = (*the_stat >> 32) & 0x00000000ffffffff;
 
     snmp_set_var_typed_value(var, ASN_COUNTER64,
-                                 (u_char *) &new_val,
-                                 sizeof(new_val));
+                             (u_char *)&new_val,
+                             sizeof(new_val));
 
     return SNMP_ERR_NOERROR;
 }
@@ -582,51 +586,51 @@ dsEntriesTable_get_value(netsnmp_request_info *request,
  */
 int
 dsEntityTable_get_value(netsnmp_request_info *request,
-                     netsnmp_index * item,
-                     netsnmp_table_request_info *table_info)
+                        netsnmp_index *item,
+                        netsnmp_table_request_info *table_info)
 {
     netsnmp_variable_list *var = request->requestvb;
-    stats_table_context *context = (stats_table_context *) item;
-                                                                                                                
+    stats_table_context *context = (stats_table_context *)item;
+
     switch (table_info->colnum) {
-                                                                                                                
+
     case COLUMN_DSENTITYDESCR:
         snmp_set_var_typed_value(var, ASN_OCTET_STR,
-                                 (u_char *) context->hdr_tbl.dsDescription,
+                                 (u_char *)context->hdr_tbl.dsDescription,
                                  strlen(context->hdr_tbl.dsDescription));
         break;
-                                                                                                                
+
     case COLUMN_DSENTITYVERS:
         snmp_set_var_typed_value(var, ASN_OCTET_STR,
-                                 (u_char *) context->hdr_tbl.dsVersion,
+                                 (u_char *)context->hdr_tbl.dsVersion,
                                  strlen(context->hdr_tbl.dsVersion));
         break;
-                                                                                                                
+
     case COLUMN_DSENTITYORG:
         snmp_set_var_typed_value(var, ASN_OCTET_STR,
-                                 (u_char *) context->hdr_tbl.dsOrganization,
+                                 (u_char *)context->hdr_tbl.dsOrganization,
                                  strlen(context->hdr_tbl.dsOrganization));
         break;
-                                                                                                                
+
     case COLUMN_DSENTITYLOCATION:
         snmp_set_var_typed_value(var, ASN_OCTET_STR,
-                                 (u_char *) context->hdr_tbl.dsLocation,
+                                 (u_char *)context->hdr_tbl.dsLocation,
                                  strlen(context->hdr_tbl.dsLocation));
         break;
-                                                                                                                
+
     case COLUMN_DSENTITYCONTACT:
         snmp_set_var_typed_value(var, ASN_OCTET_STR,
-                                 (u_char *) context->hdr_tbl.dsContact,
+                                 (u_char *)context->hdr_tbl.dsContact,
                                  strlen(context->hdr_tbl.dsContact));
         break;
-                                                                                                                
+
     case COLUMN_DSENTITYNAME:
         snmp_set_var_typed_value(var, ASN_OCTET_STR,
-                                 (u_char *) context->hdr_tbl.dsName,
+                                 (u_char *)context->hdr_tbl.dsName,
                                  strlen(context->hdr_tbl.dsName));
         break;
 
-    default:/* We shouldn't get here */
+    default: /* We shouldn't get here */
         snmp_log(LOG_ERR, "Unknown column in dsEntityTable_get_value\n");
         return SNMP_ERR_GENERR;
     }
@@ -645,11 +649,11 @@ send_DirectoryServerDown_trap(server_instance *serv_p)
     stats_table_context *ctx = NULL;
 
     /* Define the oids for the trap */
-    oid DirectoryServerDown_oid[] = { DirectoryServerDown_OID };
-    oid dsEntityDescr_oid[] = { dsEntityTable_TABLE_OID, 1, COLUMN_DSENTITYDESCR, 0 };
-    oid dsEntityVers_oid[] = { dsEntityTable_TABLE_OID, 1, COLUMN_DSENTITYVERS, 0 };
-    oid dsEntityLocation_oid[] = { dsEntityTable_TABLE_OID, 1, COLUMN_DSENTITYLOCATION, 0 };
-    oid dsEntityContact_oid[] = { dsEntityTable_TABLE_OID, 1, COLUMN_DSENTITYCONTACT, 0 };
+    oid DirectoryServerDown_oid[] = {DirectoryServerDown_OID};
+    oid dsEntityDescr_oid[] = {dsEntityTable_TABLE_OID, 1, COLUMN_DSENTITYDESCR, 0};
+    oid dsEntityVers_oid[] = {dsEntityTable_TABLE_OID, 1, COLUMN_DSENTITYVERS, 0};
+    oid dsEntityLocation_oid[] = {dsEntityTable_TABLE_OID, 1, COLUMN_DSENTITYLOCATION, 0};
+    oid dsEntityContact_oid[] = {dsEntityTable_TABLE_OID, 1, COLUMN_DSENTITYCONTACT, 0};
 
     dsEntityDescr_oid[3] = serv_p->port;
     dsEntityVers_oid[3] = serv_p->port;
@@ -660,7 +664,7 @@ send_DirectoryServerDown_trap(server_instance *serv_p)
 
     /* Lookup row to get version string */
     if ((ctx = stats_table_find_row(serv_p->port)) == NULL) {
-        snmp_log(LOG_ERR, "Malloc error finding row for server: %d\n", serv_p->port); 
+        snmp_log(LOG_ERR, "Malloc error finding row for server: %d\n", serv_p->port);
         return 1;
     }
 
@@ -668,35 +672,35 @@ send_DirectoryServerDown_trap(server_instance *serv_p)
     snmp_varlist_add_variable(&var_list,
                               snmptrap_oid, OID_LENGTH(snmptrap_oid),
                               ASN_OBJECT_ID,
-                              (u_char *) &DirectoryServerDown_oid,
+                              (u_char *)&DirectoryServerDown_oid,
                               sizeof(DirectoryServerDown_oid));
     snmp_varlist_add_variable(&var_list,
                               dsEntityDescr_oid,
                               OID_LENGTH(dsEntityDescr_oid), ASN_OCTET_STR,
-                              (u_char *) ctx->hdr_tbl.dsDescription,
+                              (u_char *)ctx->hdr_tbl.dsDescription,
                               strlen(ctx->hdr_tbl.dsDescription));
     snmp_varlist_add_variable(&var_list,
                               dsEntityVers_oid,
                               OID_LENGTH(dsEntityVers_oid), ASN_OCTET_STR,
-                              (u_char *) ctx->hdr_tbl.dsVersion,
+                              (u_char *)ctx->hdr_tbl.dsVersion,
                               strlen(ctx->hdr_tbl.dsVersion));
     snmp_varlist_add_variable(&var_list,
                               dsEntityLocation_oid,
                               OID_LENGTH(dsEntityLocation_oid),
                               ASN_OCTET_STR,
-                              (u_char *) ctx->hdr_tbl.dsLocation,
+                              (u_char *)ctx->hdr_tbl.dsLocation,
                               strlen(ctx->hdr_tbl.dsLocation));
     snmp_varlist_add_variable(&var_list,
                               dsEntityContact_oid,
                               OID_LENGTH(dsEntityContact_oid),
                               ASN_OCTET_STR,
-                              (u_char *) ctx->hdr_tbl.dsContact,
+                              (u_char *)ctx->hdr_tbl.dsContact,
                               strlen(ctx->hdr_tbl.dsContact));
 
     /* Send the trap */
     send_v2trap(var_list);
     snmp_free_varbind(var_list);
-                                                                                                                
+
     return SNMP_ERR_NOERROR;
 }
 
@@ -712,10 +716,10 @@ send_DirectoryServerStart_trap(server_instance *serv_p)
     stats_table_context *ctx = NULL;
 
     /* Define the oids for the trap */
-    oid DirectoryServerStart_oid[] = { DirectoryServerStart_OID };
-    oid dsEntityDescr_oid[] = { dsEntityTable_TABLE_OID, 1, COLUMN_DSENTITYDESCR, 0 };
-    oid dsEntityVers_oid[] = { dsEntityTable_TABLE_OID, 1, COLUMN_DSENTITYVERS, 0 };
-    oid dsEntityLocation_oid[] = { dsEntityTable_TABLE_OID, 1, COLUMN_DSENTITYLOCATION, 0 };
+    oid DirectoryServerStart_oid[] = {DirectoryServerStart_OID};
+    oid dsEntityDescr_oid[] = {dsEntityTable_TABLE_OID, 1, COLUMN_DSENTITYDESCR, 0};
+    oid dsEntityVers_oid[] = {dsEntityTable_TABLE_OID, 1, COLUMN_DSENTITYVERS, 0};
+    oid dsEntityLocation_oid[] = {dsEntityTable_TABLE_OID, 1, COLUMN_DSENTITYLOCATION, 0};
 
     dsEntityDescr_oid[3] = serv_p->port;
     dsEntityVers_oid[3] = serv_p->port;
@@ -733,28 +737,28 @@ send_DirectoryServerStart_trap(server_instance *serv_p)
     snmp_varlist_add_variable(&var_list,
                               snmptrap_oid, OID_LENGTH(snmptrap_oid),
                               ASN_OBJECT_ID,
-                              (u_char *) &DirectoryServerStart_oid,
+                              (u_char *)&DirectoryServerStart_oid,
                               sizeof(DirectoryServerStart_oid));
     snmp_varlist_add_variable(&var_list,
                               dsEntityDescr_oid,
                               OID_LENGTH(dsEntityDescr_oid), ASN_OCTET_STR,
-                              (u_char *) ctx->hdr_tbl.dsDescription,
+                              (u_char *)ctx->hdr_tbl.dsDescription,
                               strlen(ctx->hdr_tbl.dsDescription));
     snmp_varlist_add_variable(&var_list,
                               dsEntityVers_oid,
                               OID_LENGTH(dsEntityVers_oid), ASN_OCTET_STR,
-                              (u_char *) ctx->hdr_tbl.dsVersion,
+                              (u_char *)ctx->hdr_tbl.dsVersion,
                               strlen(ctx->hdr_tbl.dsVersion));
     snmp_varlist_add_variable(&var_list,
                               dsEntityLocation_oid,
                               OID_LENGTH(dsEntityLocation_oid),
                               ASN_OCTET_STR,
-                              (u_char *) ctx->hdr_tbl.dsLocation,
+                              (u_char *)ctx->hdr_tbl.dsLocation,
                               strlen(ctx->hdr_tbl.dsLocation));
-                                                                                                                
+
     /* Send the trap */
     send_v2trap(var_list);
     snmp_free_varbind(var_list);
-                                                                                                                
+
     return SNMP_ERR_NOERROR;
 }
