@@ -21,6 +21,8 @@
 #include "ldap.h"
 #include "ldif.h"
 #include <ctype.h>
+#include <limits.h>
+#include <errno.h>
 
 static char *agentx_master = NULL;
 static char *agent_logdir = NULL;
@@ -54,8 +56,22 @@ main(int argc, char *argv[])
     {
         char *s = getenv("DEBUG_SLEEP");
         if ((s != NULL) && isdigit(*s)) {
-            int secs = atoi(s);
-            printf("%s pid is %d\n", argv[0], getpid());
+            char *endp = NULL;
+            int64_t secs;
+            errno = 0;
+
+            secs = strtol(s, &endp, 10);
+            if ( endp == s ||
+                 *endp != '\0' ||
+                 ((secs == LONG_MIN || secs == LONG_MAX) && errno == ERANGE) ||
+                 secs < 1 )
+            {
+                /* Invalid value, default to 30 seconds */
+                secs = 30;
+            } else if (secs > 3600) {
+                secs = 3600;
+            }
+            printf("%s pid is %d - sleeping for %ld\n", argv[0], getpid(), secs);
             sleep(secs);
         }
     }
